function varargout = quantify(varargin)
% QUANTIFY M-file for quantify.fig
%
%   Known bugs:
%       Samples with more than 1000 compounds and compounds with more than 
%           30 peaks may cause problems (due to the variable Singlevalues)
%
%   Change requests:
%
%       Must-have changes:
%
%       Nice-to-have changes:
%           Include warning if no replicates were found
%           Dilution factors with more or less than 4 digits
%
%   Change log:
%
%   Changes for version 1.1 (01 June 2012):
%       Summary: Minor and major functional changes and bug fixes
%
%       Added function: The user may allow single peaks to miss for each
%           molecule. This might be useful for molecule with few peaks that
%           migt drop below the peak threshold when just one peak is not 
%           found in the spectrum.
%       In the configuration sheet: Factors and the QUANTIFY version are 
%           now saved with a preceding ' instead of a following _ to avoid 
%           automatic Excel format conversions (' is not displayed by
%           Excel)
%       Waitbar is initialized only when a valid output file name was
%           chosen
%       Fixed an error that occurred when MATLAB 7.1 was used in 
%           combination with Excel 2003. In these cases, a .xls output file
%           is created instead of a .xlsx file.
%       Added a check for dots (.) in the output file name as these might
%           cause problems with the file extension
%       Changed the internal data format for peak integrals in a manner
%           that also negative peak integrals are allowed now. Compound 
%           titles etc. are marked as negative complex numbers now, e.g. 
%           -3-i
%       Added a check whether the compounds have the same order in each
%           sample. In case the order differs, the compounds are ordered as
%           in the first sample.
%       Compounds for which no entries are availale in some samples are now
%           set to zero. The number of used peaks is set to (0/0).
%       German variable names have been changed to English names
%       Added a warning in case dilution correction was selected but no
%           dilution factors were found. This warning is saved in the 
%           configuration sheet
%       In case dilution correction or normalization to a specific compound
%           was selected, the uncorrected values are not stored in a sheet
%           named "Values", but in a sheet named "Uncorrected Values" to
%           avoid confusions
%       Bugfix: In case the number of peaks available for one compound is 
%           not the same in all samples, the number of used peaks and the 
%           quantification results may have been incorrect. Reason: The 
%           values of the preceding sample were not set to zero in these 
%           cases and were mixed up with the values from the current 
%           sample. This bug was fixed.
%       Bugfix: In case a peak integral file had much less compounds in the
%           second or third sample, not all compound concentrations were
%           calculated and saved. Reason: The loop for calculating means 
%           stoped too early. This bug was fixed.
%       Calibration factors must now be zero for not-used peaks! Negative
%           factors may now be used for quantifying negative peak 
%           integrals. 
%       An error message is displayed in case the AMIX file was calculated
%            with the option "short" instead of "detailed"
%       Upon all standard error messgaes, the progress bar is closed now
%       LLOQ was said to be "Not used" in the configuration sheet even
%           when it was actually used. This bug was fixed.
%       Warnings were written one field "too high" in the configuration 
%           sheet. This bug was fixed.
%       The reference substance concentration is no longer written to the
%          configuration sheet in case no scaling was used.
%       Fields "Missing obligatory peaks", "Too few peaks" and "Accepted
%          after probability check" were saved one field too high in the
%          configuration sheet, thus overwriting the number of outliers.
%          This bug was fixed.
%       When choosing a file, the file browser now jumps to the directory
%           that was last used for this kind of file.
%       The sheet "Used peaks" was renamed to "Used Peaks"
%
%
%
%   Changes for version 1.0:
%       Text ouptut file for final results was renamed to "...results.txt"
%          (was "...final.txt" before)
%       Abbreviations of standard deviation, technical error etc. were 
%           replaced in the spreadsheets "Results" and "Mean"
%       Pop-up menus with input file types in panels 1, 2 and 3 were 
%           changed into (inactive) text fields to avoid erroneous file 
%           type changes
%       Scaling to reference substance is also possible now in combination
%           with using a peak inforamtion file
%       Tooltips were reworked
%       Descriptive text fields were added in panels 2 and 3
%       A progress bar was added to visualize the quantification progress
%       
%
%   Changes for version date 15-Sep-2011:
%       Corrected Excel file extension. In newer Excel versions, .xlsx will
%           be used now automatically, in older version .xls will be used.
%           Before, in newer Excel versions .xlsx format was used with .xls
%           file extension. This caused error messages.
%
%   Changes for version date 27-Jun-2011:
%       TEM equation corrected: sqrt(ED^2/2*i) instead of sqrt(2*ED^2/i)
%           TEM was too higher by factor 2 before!
%
%   Changes for version date 20-Jun-2011:
%       Compiled with Matlab R2007b
%
%   Changes for version date 17-Jun-2011:
%       Loading and saving custom parameter files is now only possible in
%           Matlab binary file format (didn't work for other file types)
%       Description of the "Quantify!"-button was updated
%       ";" after "else" was removed in the whole code
%       In the "Configuration" sheet: When using text files as integral
%          files, peak information files or LLOQ files, "Not used" is 
%          written into the fields "Sheet" and "Range" (instead of ranges)
%       Program does no longer crash when a compound isn't found in the
%           peak information file
%   
%   Changes for version date 28-Feb-2011:
%       Rework of the GUI, addition of menu bar
%       Changed checkmark in "1" and "2" from "Don't use..." to "Enable"
%       Starts with default values now, added button "Load custom
%           parameters"
%       Added field for the selected files
%       Added pop-up menus for file types
%       Less global variables - All parameters are read from the figure,
%           not from "hidden" variables (versiondate is last global
%           variable)
%       Quantify!-button is no longer deactivated but activated from start
%       Changed names of text fields and panels to match the respective 
%           variables, e.g. text1 is now outl_thr_text
%       Warning and error windows pop up instead of status window messages
%       Removed the time stamp messages. No status messages any more, so no
%           DOS status window is needed any more.
%       Information sheet/file renamed to Configuration; added missing
%           configuration values
%       Bug to be fixed: When a compound is not found the program crashes
%   
%   Changes for version date 10-Feb-2011:
%       Added example in the pop-up-description for "Correction factor"
%       (Example is 0.5804, the factor for our old TSP solution, just as a
%       reminder)
%       Changed "Info" sheet/file: Only two columns instead of 4; When no
%       errors occurred this will be stated in the "Errors and warnings"
%       line
%
%   Changes for version date 05-Jan-2011:
%       Missing peak information or missing LLOQs do no longer stop the 
%       program. In the first case, no value is calculated, in the second
%       case no LLOQ checking is done.
%
%   Changes for version date 04-Jan-2011 (2011-12-04):
%       A bug occurring when xls output filenames contained "." was removed
%       The "Exit" button now only exits the program and does no longer 
%       save any parameters. A new button "Save parameters" was introduced 
%       for this reason.
%
%   Changes for version date 29-Nov-2010 (2010-11-29):
%       Compounds where peaks were excluded are no longer stored as 
%       negative values, to avoid confusions.
%
%   End of the change log
%
%      QUANTIFY, by itself, creates a new QUANTIFY or raises the existing
%      singleton*.
%
%      H = QUANTIFY returns the handle to a new QUANTIFY or the handle to
%      the existing singleton*.
%
%      QUANTIFY('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in QUANTIFY.M with the given input arguments.
%
%      QUANTIFY('Property','Value',...) creates a new QUANTIFY or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before quantify_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to quantify_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help quantify

% Last Modified by GUIDE v2.5 30-Mar-2012 14:01:51

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @quantify_OpeningFcn, ...
                   'gui_OutputFcn',  @quantify_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before QUANTIFY is made visible.
function quantify_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to QUANTIFY (see VARARGIN)

% Choose default command line output for QUANTIFY
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes QUANTIFY wait for user response (see UIRESUME)
% uiwait(handles.figure1);

global versiondate excelExtension OriginalFolder IntegralFolder InformationFolder LLOQFolder SaveFolder

versiondate='1.1';

Excel = actxserver('Excel.Application');
 % Excel verison 11 = 2003 -> .xls, version 12.0 = 2007 -> .xlsx
 excelVersion = str2double(Excel.Version);
 if excelVersion < 12
    excelExtension = '.xls';
 else
    excelExtension = '.xlsx';
 end
 Excel.Quit
 Excel.delete
 clear Excel;

OriginalFolder=cd;
IntegralFolder=OriginalFolder;
InformationFolder=OriginalFolder;
LLOQFolder=OriginalFolder;
SaveFolder=OriginalFolder; 
 
%load default values
loaddefaults_Callback(handles.loaddefaults,eventdata,handles);

%display "about" message
%about_Callback(handles.about,eventdata,handles);


% --- Outputs from this function are returned to the command line.
function varargout = quantify_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

% --- Executes on button press in loaddefaults.
function loaddefaults_Callback(hObject, eventdata, handles)

%define default values

global OriginalFolder IntegralFolder InformationFolder LLOQFolder SaveFolder

IntegralFolder=OriginalFolder;
InformationFolder=OriginalFolder;
LLOQFolder=OriginalFolder;
SaveFolder=OriginalFolder;

inputfile_iddefault=1;
corr_iddefault=1;
LLOQ_iddefault=1;
information_file_entry_default = '';
LLOQ_file_entry_default = '';
information_file_entry_default2='off';
LLOQ_file_entry_default2='off';
peak_inormation_popupmenu_default2='off';
LLOQ_popupmenu_default2='off';

refsubstancedefault=0;
creanormdefault=1;
dilcorrdefault=1;
meancalcdefault=1;
noLLOQsdefault=0;
noindividualcalibfactorsdefault=0;
corrfactordefault='1.0';
dilfactordefault='1.0';
outl_thrdefault='0.4';
peak_thrdefault='0.66';

singlepeaksmissingdefault=1;

refsubstancenamedefault='tmsp';
creanormnamedefault='creatinine';
refsubstconcdefault='1.0';
xlssheetdefault='Integrals';
xlsrangedefault='A2:B5000';
calibsheetdefault='Factors';
calibrangedefault='A2:D5000';
LLOQsheetdefault='LLOQs';
LLOQrangedefault='A2:B5000';

xlssheetdefault2='off';
xlsrangedefault2='off';
xlsrange_textdefault2='off';
xlssheet_textdefault2='off';
openLLOQSdefault2='off';
LLOQsheetdefault2='off';
LLOQsheet_textdefault2='off';
LLOQrange_textdefault2='off';
LLOQrangedefault2='off';
refsubstancenamedefault2='off';
opencalibrationfactorsdefault2='off';
calibsheetdefault2='off';
calibsheet_textdefault2='off';
calibrange_textdefault2='off';
calibrangedefault2='off';
refsubstconcdefault2='off';
refsubstconc_textdefault2='off';
saveasdefault2='on';

information_file_entry_textdefault='off';
inormation_popupmenu_textdefault='off';
LLOQ_file_entry_textdefault='off';
LLOQ_popupmenu_textdefault='off';

%remove earlier integral file names to reduce confusions
set(handles.integral_file_entry,'String','');

%set default values
set(handles.refsubstance,'Value',refsubstancedefault);
set(handles.creanorm,'Value',creanormdefault);
set(handles.dilcorr,'Value',dilcorrdefault);
set(handles.meancalc,'Value',meancalcdefault);
set(handles.noLLOQs,'Value',noLLOQsdefault);
set(handles.noindividualcalibfactors,'Value',noindividualcalibfactorsdefault);
set(handles.corrfactor,'String',corrfactordefault);
set(handles.dilfactor,'String',dilfactordefault);
set(handles.outl_thr,'String',outl_thrdefault);
set(handles.peak_thr,'String',peak_thrdefault);
set(handles.singlepeaksmissing,'Value',singlepeaksmissingdefault);
set(handles.refsubstancename,'String',refsubstancenamedefault);
set(handles.creanormname,'String',creanormnamedefault);
set(handles.LLOQ_popupmenu,'Value',LLOQ_iddefault);
set(handles.peak_inormation_popupmenu,'Value',corr_iddefault);
set(handles.integral_popupmenu,'Value',inputfile_iddefault);
set(handles.information_file_entry,'String',information_file_entry_default);
set(handles.LLOQ_file_entry,'String',LLOQ_file_entry_default);
set(handles.information_file_entry,'Enable',information_file_entry_default2);
set(handles.LLOQ_file_entry,'Enable',LLOQ_file_entry_default2);
set(handles.peak_inormation_popupmenu,'Enable',peak_inormation_popupmenu_default2);
set(handles.LLOQ_popupmenu,'Enable',LLOQ_popupmenu_default2);

set(handles.refsubstconc,'String',refsubstconcdefault);
set(handles.xlssheet,'String',xlssheetdefault);
set(handles.xlsrange,'String',xlsrangedefault);
set(handles.calibsheet,'String',calibsheetdefault);
set(handles.calibrange,'String',calibrangedefault);
set(handles.LLOQsheet,'String',LLOQsheetdefault);
set(handles.LLOQrange,'String',LLOQrangedefault);
set(handles.xlssheet,'Enable',xlssheetdefault2);
set(handles.xlsrange,'Enable',xlsrangedefault2);
set(handles.xlsrange_text,'Enable',xlsrange_textdefault2);
set(handles.xlssheet_text,'Enable',xlssheet_textdefault2);
set(handles.openLLOQS,'Enable',openLLOQSdefault2);
set(handles.LLOQsheet,'Enable',LLOQsheetdefault2);
set(handles.LLOQsheet_text,'Enable',LLOQsheet_textdefault2);
set(handles.LLOQrange_text,'Enable',LLOQrange_textdefault2);
set(handles.LLOQrange,'Enable',LLOQrangedefault2);
set(handles.refsubstancename,'Enable',refsubstancenamedefault2);
set(handles.opencalibrationfactors,'Enable',opencalibrationfactorsdefault2);
set(handles.calibsheet,'Enable',calibsheetdefault2);
set(handles.calibsheet_text,'Enable',calibsheet_textdefault2);
set(handles.calibrange_text,'Enable',calibrange_textdefault2);
set(handles.calibrange,'Enable',calibrangedefault2);
set(handles.refsubstconc,'Enable',refsubstconcdefault2);
set(handles.refsubstconc_text,'Enable',refsubstconc_textdefault2);
set(handles.saveas,'Enable',saveasdefault2);

set(handles.information_file_entry_text,'Enable',information_file_entry_textdefault);
set(handles.peak_inormation_popupmenu_text,'Enable',inormation_popupmenu_textdefault);
set(handles.LLOQ_file_entry_text,'Enable',LLOQ_file_entry_textdefault);
set(handles.LLOQ_popupmenu_text,'Enable',LLOQ_popupmenu_textdefault);


% --- Executes on button press in about.
function about_Callback(hObject, eventdata, handles)

global versiondate

About_text='QUANTIFY\nVersion: %s\n\nAuthor: Matthias S. Klein\nInstitute of Functional Genomics\nUniversity of Regensburg, Regensburg, Germany\nEmail: matthias.klein@klinik.uni-r.de\n\n';
msgbox(sprintf(About_text,versiondate),'About Quantify');
%fprintf(About_text,versiondate);


% --- Executes on button press in saveas.
function saveas_Callback(hObject, eventdata, handles)

global versiondate excelExtension SaveFolder
%error catching to produce pop-up error messages
try
%read and check all input parameters and file names

filename = strtrim(get(handles.integral_file_entry,'String'));
if isempty(filename)
    msgbox('Please specify a peak integral file!','Error','error');
    return
else
    if not(exist(filename,'file'))
        msgbox('Peak integral file not found!','Error','error');
        return
    end
end

calibrationfactorsfile = strtrim(get(handles.information_file_entry,'String'));
no_calibrationfactors=get(handles.noindividualcalibfactors,'Value');

if no_calibrationfactors==1
    if isempty(calibrationfactorsfile)
        msgbox('Please specify a peak information file!','Error','error');
        return
    else
        if not(exist(calibrationfactorsfile,'file'))
            msgbox('Peak information file not found!','Error','error');
            return
        end
    end
end

LLOQfile = strtrim(get(handles.LLOQ_file_entry,'String'));
dontuse_LLOQS=get(handles.noLLOQs,'Value');%0=use LLOQs, 1=dont use LLOQs

if dontuse_LLOQS==1
    if isempty(LLOQfile)
        msgbox('Please specify a file with lower limits of quantification!','Error','error');
        return
    else
        if not(exist(LLOQfile,'file'))
            msgbox('Lower limits of quantification file not found!','Error','error');
            return
        end
    end
end

spikeinfactor=str2num(get(handles.corrfactor,'String'));

if isempty(spikeinfactor)
    msgbox('Please specify a correction factor!','Error','error');
    return
%else
    %if spikeinfactor<=0
    %    msgbox('Please specify a correction factor larger than 0!','Error','error');
    %    return
    %end
end

dilutionfactor=str2num(get(handles.dilfactor,'String'));

if isempty(dilutionfactor)
    msgbox('Please specify a dilution factor!','Error','error');
    return
%else
%    if dilutionfactor<=0
%        msgbox('Please specify a dilution factor larger than 0!','Error','error');
%        return
%    end
end

Outliervalue=str2num(get(handles.outl_thr,'String'));

if isempty(Outliervalue)
    msgbox('Please specify an outlier threshold larger than 0!','Error','error');
    return
else
    if Outliervalue<=0
        msgbox('Please specify an outlier threshold larger than 0!','Error','error');
        return
    end
end

Peakthreshold=str2num(get(handles.peak_thr,'String'));

if isempty(Peakthreshold)
    msgbox('Please specify a peak threshold between 0 and 1!','Error','error');
    return
else
    if Peakthreshold<=0||Peakthreshold>1
        msgbox('Please specify a peak threshold between 0 and 1!','Error','error');
        return
    end
end

scale2refsubst=get(handles.refsubstance,'Value');%0=no scaling, 1=scaling
refsubstname=strtrim(get(handles.refsubstancename,'String'));

if scale2refsubst==1&&isempty(refsubstname)
    msgbox('Please specify a reference substance for scaling!','Error','error');
    return
end

if scale2refsubst==1
    refsubstanceconcentration=str2num(strtrim(get(handles.refsubstconc,'String')));
else
    refsubstanceconcentration=1;
end

if isempty(refsubstanceconcentration)
    msgbox('Please specify a reference substance concentration!','Error','error');
    return
%else
%    if refsubstanceconcentration<=0
%        msgbox('Please specify a reference substance concentration larger than 0!','Error','error');
%        return
%    end
end

crea_correction=get(handles.creanorm,'Value');
crea_correction_compound=strtrim(get(handles.creanormname,'String'));

if crea_correction==1&&isempty(crea_correction_compound)
    msgbox('Please specify a substance for normalization!','Error','error');
    return
end

dil_correction=get(handles.dilcorr,'Value');
singlepeaksmissingallowed=get(handles.singlepeaksmissing,'Value');

inputfile_id = get(handles.integral_popupmenu,'Value');
LLOQ_id = get(handles.LLOQ_popupmenu,'Value');
corr_id = get(handles.peak_inormation_popupmenu,'Value');

pause on;
pause(0.075);%pause for a small time to let windows redraw

mean_calculation=get(handles.meancalc,'Value');
xls_integralsheet=get(handles.xlssheet,'String');
xls_integralarea=get(handles.xlsrange,'String');
calibrationfilepage=get(handles.calibsheet,'String');
calibrationfilearea=get(handles.calibrange,'String');
LLOQpage=get(handles.LLOQsheet,'String');
LLOQrange=get(handles.LLOQrange,'String');

errorlist={'a'};
errorlist=[];
LLOQnotfound_warning=0;
NumberbelowLLOQ=0;
NumberOutliers=0;
Crea_Count=0;
dfexist=0;
i_MEAN=0;
numberpeakcountlowerthanthreshold=0;
numberpeakcountlowerthanthresholdexcluded=0;
Obligatorypeakmissing=0;
Outlierslist={'Sample' 'Compound' 'Value1' 'Value2' 'Value3' 'Value4'...
    'Value5' 'Value6' 'Value7' 'Value8' 'Value9' 'Value10' 'Value11' ...
    'Value12' 'Value13' 'Value14' 'Value15' 'Value16' 'Value17' 'Value18'...
    'Value19' 'Value20' 'Value21' 'Value22' 'Value23' 'Value24' 'Value25'...
    'Value26' 'Value27' 'Value28' 'Value29' 'Value30'};
ValuesTitlecolumn(1)={'mmol/L'};
Singlevalues=zeros(30,1000);

%get output filename
cd(SaveFolder);
[outputfilename, outputpathname, output_id] = uiputfile({strcat('*',...
    excelExtension),strcat('MS Excel file (',excelExtension,')');...
    '*.txt','Tab stop separated .txt'},'Save results as','Results');
outputfile=strcat(outputpathname,outputfilename);
if output_id==0
    return
else
    SaveFolder=outputpathname;
    cd(SaveFolder);
end
try
    close(waitbar_progress)
end
waitbar_progress = waitbar(0,'','Name','Please wait...');
if ishandle(waitbar_progress)
    waitbar(0,waitbar_progress,'Initializing...')
end
%xlsfile
if output_id==1
     outputfilenameminusextension=strrep(outputfilename,'.xlsx','');
     outputfilenameminusextension=strrep(outputfilenameminusextension,'.xls','');
     outputfileminusextension=strcat(outputpathname,outputfilenameminusextension);
     outputfileplusextension=strcat(outputfileminusextension,excelExtension);
%     if isempty(strfind(outputfilename,excelExtension))
%         outputfileplusextension=strcat(outputpathname,outputfilename,excelExtension);
%         outputfileminusextension=strcat(outputpathname,outputfilename);
%     else
%         outputfileplusextension=strcat(outputpathname,outputfilename);
%         outputfileminusextension=strrep(outputfilename,'.xlsx','');
%         outputfileminusextension=strrep(outputfileminusextension,'.xls','');
%         outputfileminusextension=strcat(outputpathname,outputfileminusextension);
%     end
    if isempty(strfind(outputfilenameminusextension,'.'))
    %
    else
        msgbox('Please do not use dots (.) in your output file name. There might be problems with the file extension.','Warning','warn');
        %fprintf('Warning: The peak info file does not seem to be valid');
        %fprintf(' (please exclude headlines)!\n');
        errorlist{length(errorlist)+1}='Please do not use dots (.) in your output file name. There might be problems with the file extension.';
    end
end
%txt file
if output_id==2
    if isempty(strfind(outputfilename,'.txt'))
        outputfileplusextension=strcat(outputpathname,outputfilename,'.txt');
        outputfileminusextension=strrep(outputfileplusextension,'.txt','');
    else
        outputfileplusextension=strcat(outputpathname,outputfilename);
        outputfileminusextension=strrep(outputfileplusextension,'.txt','');
    end
end
recycle on;
pause(0.075);%pause for a small time to let windows redraw
if exist(outputfileplusextension)==2
    delete(outputfileplusextension);
end

%read peak information from xls file
if corr_id==1&&no_calibrationfactors==1
    if ishandle(waitbar_progress)
        waitbar(1/7,waitbar_progress,'Reading peak information file...')
    end
    %fprintf('Reading peak information from MS Excel file... ');
    %tic;
    [calibfactor,calibfactortext]=xlsread(calibrationfactorsfile,calibrationfilepage,...
        calibrationfilearea);
    %t=toc;
    %fprintf('Done in %g seconds.\n',t);
    if abs(length(calibfactor)-length(calibfactortext))>1
        msgbox('The peak information file does not seem to be valid. Please exclude headlines.','Warning','warn');
        %fprintf('Warning: The peak information file does not seem to be valid ');
        %fprintf('(please exclude headlines)!\n');
        errorlist{length(errorlist)+1}='The peak information file does not seem to be valid. Please exclude headlines.';
    end
end

%read peak information from txt file
if corr_id==2&&no_calibrationfactors==1
    if ishandle(waitbar_progress)
        waitbar(1/7,waitbar_progress,'Reading peak information file...')
    end
    %fprintf('Reading peak information from tab stop separated text file... ');
    %tic;
    informationreadingstring='%s%s%s%s';
    fid = fopen(calibrationfactorsfile);
    textscan(fid,informationreadingstring,1,'delimiter','\t');%ignore headline
    calibfactorinput=textscan(fid,informationreadingstring,1,'delimiter','\t');
    calibfactortext(1)={''};
    calibfactortext(1)=[];
    calibfactor=[];
    calibfactorlength=0;
    calibfactortext(length(calibfactortext)+1)=calibfactorinput{1};
    %skip first (empty) line of values. this is to achieve the same data
    %structure as when values are read from excel
    while feof(fid) == 0
        calibfactorinput=textscan(fid,informationreadingstring,1,'delimiter','\t');
        calibfactortext(length(calibfactortext)+1)=calibfactorinput{1};
        calibfactorintermediatetext(1)=calibfactorinput{2};
        calibfactorintermediatetext(2)=calibfactorinput{3};
        calibfactorintermediatetext(3)=calibfactorinput{4};
        if isempty(calibfactorintermediatetext{1})
            calibfactor(calibfactorlength+1,1)=NaN;
        else
            calibfactor(calibfactorlength+1,1)=str2num(calibfactorintermediatetext{1});
        end
        if isempty(calibfactorintermediatetext{2})
            calibfactor(calibfactorlength+1,2)=NaN;
        else
            calibfactor(calibfactorlength+1,2)=str2num(calibfactorintermediatetext{2});
        end
        if isempty(calibfactorintermediatetext{3})
            calibfactor(calibfactorlength+1,3)=NaN;
        else
            calibfactor(calibfactorlength+1,3)=str2num(calibfactorintermediatetext{3});
        end
        calibfactorlength=length(calibfactor(:,1));
    end
    fclose(fid);
    calibfactortext=calibfactortext';
    clear calibfactorintermediatetext calibfactorinput;
    %t=toc;
    %fprintf('Done in %g seconds.\n',t);
    if abs(length(calibfactor)-length(calibfactortext))>1
        msgbox('The peak information file does not seem to be valid. Please exclude headlines.','Warning','warn');
        %fprintf('Warning: The peak info file does not seem to be valid');
        %fprintf(' (please exclude headlines)!\n');
        errorlist{length(errorlist)+1}='The peak information file does not seem to be valid. Please exclude headlines.';
    end
end

%read LLOQs from xls file
if dontuse_LLOQS==1&&LLOQ_id==1
    if ishandle(waitbar_progress)
        waitbar(2/7,waitbar_progress,'Reading LLOQ file...')
    end
    %fprintf('Reading LLOQs from MS Excel file... ');
    %tic;
    [LLOQ,LLOQtext]=xlsread(LLOQfile,LLOQpage,LLOQrange);
    %t=toc;
    %fprintf('Done in %g seconds.\n',t);
    if abs(length(LLOQ)-length(LLOQtext))>0
        msgbox('The limit of quantification file does not seem to be valid. Please exclude headlines.','Warning','warn');
        %fprintf('Warning: The LLOQ file does not seem to be valid');
        %fprintf(' (please exclude headlines)!\n');
        errorlist{length(errorlist)+1}='The limit of quantification file does not seem to be valid. Please exclude headlines.';
    end   
end
%read LLOQs from tab stop txt file
if dontuse_LLOQS==1&&LLOQ_id==2
    if ishandle(waitbar_progress)
        waitbar(2/7,waitbar_progress,'Reading LLOQ file...')
    end
    %fprintf('Reading LLOQs from tab stop separated text file... ');
    %tic;
    LLOQreadingstring='%s%s';
    fid = fopen(LLOQfile);
    textscan(fid,LLOQreadingstring,1,'delimiter','\t');%ignore headline
    LLOQinput=textscan(fid,LLOQreadingstring,1,'delimiter','\t');
    LLOQtext(1)={''};
    LLOQtext(1)=[];
    LLOQ=[];
    while feof(fid) == 0
        LLOQtext(length(LLOQtext)+1)=LLOQinput{1};
        LLOQintermediatetext=LLOQinput{2};
        LLOQ(length(LLOQ)+1)=str2num(LLOQintermediatetext{1});
        LLOQinput=textscan(fid,LLOQreadingstring,1,'delimiter','\t');
    end
    fclose(fid);
    clear LLOQinput LLOQintermediatetext;
    %t=toc;
    %fprintf('Done in %g seconds.\n',t);
    if abs(length(LLOQ)-length(LLOQtext))>0
        msgbox('The limit of quantification file does not seem to be valid. Please exclude headlines.','Warning','warn');
        %fprintf('Warning: The LLOQ file does not seem to be valid ');
        %fprintf('(please exclude headlines)!\n');
        errorlist{length(errorlist)+1}='The limit of quantification file does not seem to be valid. Please exclude headlines.';
    end   
end

%create cell array for title, names etc.
data1(1)={''};
data1(1)=[];
data2=[];%vector for integrals
%read integrals from amix text file
%The integral will be saved in the two vectors data1 and data2. data1 
%contains the names of the compounds and peaks, data2 contains the values. 
%This is because matlab can't save strings and values into one matrix. A 
%new spectrum starts with "title:*" in data1 and with "-3-i" in data2. A new 
%compound starts with its name in data1 and with "-2-i" in data2. Unused 
%peaks are marked as -1-i in data2. Example:
%	data1			data2
%
%	title:sample1	-3-i
%	alanine         -2-i
%	C1H1			17.456
%	C2H2			16.490
%	creatinine		-2-i
%	C1H1			0.453
%	C3H3			0.671
%	title:sample2	-3-i
%	alanine         -2-i
%	etc.			etc.
%
if inputfile_id==1
    if ishandle(waitbar_progress)
        waitbar(3/7,waitbar_progress,'Reading peak integral file...')
    end
    %fprintf('Reading integrals from Amix file... ');
    %tic;
    readingstring='%s%*s%s%*s%*s%*s';
    fid = fopen(filename);
    datainput=textscan(fid,readingstring,1,'delimiter','\t');
    data1tmp='';
    while strncmp(data1tmp,'Spectrum:',9) == 0
        datainput=textscan(fid,readingstring,1,'delimiter','\t');
        data1tmp=datainput{1};
        %1D or 2D data (in amix files)? In case of 2D data use only 2D data
        if strncmp(data1tmp,'HSQC',4) == 1 
                readingstring='%s%*s%*s%*s%*s%*s%s%*s%*s%*s%*s%*s';
        end
    end
    %read first title
    while feof(fid) == 0
        if strncmp(data1tmp,'Spectrum:',9) == 1
            while strncmp(data1tmp{1},'title: ',7) == 0
                datainput=textscan(fid,readingstring,1,'delimiter','\t');
                if length(datainput{1})==0
                    msgbox('Format error in the Amix txt file, possibly due to the Amix result parameter "short" instead of "detailed". Make sure to use exactly the Amix parameters given in the manual.','Error','error');
                    if ishandle(waitbar_progress)
                        close(waitbar_progress)
                    end
                    return
                end
                data1tmp=datainput{1};
            end
            data1(length(data1)+1)=strtrim(datainput{1});
            data2(length(data2)+1)=-3-i;%-3-i marks a new spectrum title
            %find starting line of next compound
            datainput=textscan(fid,readingstring,1,'delimiter','\t');
            data1tmp=datainput{1};
            while strncmp(strtrim(data1tmp{1}),'compound',8) == 0
                datainput=textscan(fid,readingstring,1,'delimiter','\t');
                data1tmp=datainput{1};
            end
        end
        datainput=textscan(fid,readingstring,1,'delimiter','\t');
        data1tmp=datainput{1};
        data2tmp=datainput{2};
        if feof(fid) == 0
            if strncmp(data1tmp{1},'Spectrum:',9) == 0
                data1(length(data1)+1)=strtrim(data1tmp(1));
                if isempty(strtrim(data2tmp{1}))
                    data2(length(data2)+1)=-2-i;%-2-i marks a new compound
                else
                    if isempty(str2num(strtrim(data2tmp{1})))%'not used' fields
                        data2(length(data2)+1)=-1-i;%-1-i marks "not used" peaks
                    else
                    data2(length(data2)+1)=str2num(strtrim(data2tmp{1}));
                    end
                end
            end
        end
    end
    fclose(fid);
    clear datainput data1tmp data2tmp;
    %t=toc;
    if isempty(data1)
        msgbox('Data format not supported. No AMIX file?','Error','error');
        %fprintf('\nError: Data format not supported. \nNo AMIX file?\n');
        if ishandle(waitbar_progress)
            close(waitbar_progress)
        end
        return
    end
    %fprintf('Done in %g seconds.\n',t);
end
%read integrals from tab stop separated file
if inputfile_id==2
    if ishandle(waitbar_progress)
        waitbar(3/7,waitbar_progress,'Reading peak integral file...')
    end
    %fprintf('Reading integrals from tab stop separated text file... ');
    %tic;
    readingstring='%s%s';
    fid = fopen(filename);
    while feof(fid) == 0
        datainput=textscan(fid,readingstring,1,'delimiter','\t');
        data1tmp=datainput{1};
        data2tmp=datainput{2};
        %find beginning of spectrum (marked by 'title:')
        if strncmp(data1tmp,'title:',6) == 1
            data1(length(data1)+1)=strtrim(strrep(datainput{1},'title:',''));
            data2(length(data2)+1)=-3-i;%-3-i marks a new spectrum title
            %find starting line of next compound (1 empty line)
            datainput=textscan(fid,readingstring,1,'delimiter','\t');
            datainput=textscan(fid,readingstring,1,'delimiter','\t');
            data1tmp=datainput{1};
            data2tmp=datainput{2};
        end
        if strncmp(data1tmp{1},'title:',6) == 0
            if not(isempty(strtrim(data1tmp{1})))%ignore empty lines
                data1(length(data1)+1)=strtrim(data1tmp(1));
                if isempty(strtrim(data2tmp{1}))
                    data2(length(data2)+1)=-2-i;%-2-i marks a new compound
                else
                    if isempty(str2num(strtrim(data2tmp{1})))%'not used' fields
                        data2(length(data2)+1)=-1-i;%-1-i marks "not used" peaks
                    else
                        if length(data2(length(data2)))==length(str2num(strtrim(data2tmp{1})))
                            data2(length(data2)+1)=str2num(strtrim(data2tmp{1}));
                        else
                            msgbox('Integral file does not comply to the requirements in the manual.','Error','error');
                            %fprintf('\nError: Data format not supported. \nPlease check the file for compliance to the requirements in the manual.\n');
                            if ishandle(waitbar_progress)
                                close(waitbar_progress)
                            end
                            return
                        end
                    end
                end
            end
        end
    end
    fclose(fid);
    clear datainput data1tmp data2tmp;
    %t=toc;
    %fprintf('Done in %g seconds.\n',t);
end

%read from excel file
if inputfile_id==3
    if ishandle(waitbar_progress)
        waitbar(3/7,waitbar_progress,'Reading peak integral file...')
    end
    %fprintf('Reading integrals from MS Excel file... ');
    %tic;
    [integralfactor,integralname,integralraw]=xlsread(filename,...
        xls_integralsheet,xls_integralarea);
    clear integralfactor integralname;
    for i_xlsinput=1:length(integralraw)
        data1tmp=integralraw(i_xlsinput,1);
        data2tmp=integralraw(i_xlsinput,2);
        %find beginning of spectrum (marked by 'title:')
        if strncmp(data1tmp,'title:',6) == 1
            data1(length(data1)+1)=data1tmp;
            data2(length(data2)+1)=-3-i;%-3-i marks a new spectrum title
            %find starting line of next compound (1 empty line)
        else
            %ignore empty lines, these give NaN
            if ~isequalwithequalnans(data1tmp{1},NaN)
                data1(length(data1)+1)=strtrim(data1tmp);
                if isa(data2tmp{1},'char')
                    if isempty(strtrim(data2tmp{1}))
                        data2(length(data2)+1)=-2-i;
                        %-2-i marks a new compound, no entry in field (spaces)
                    else
                        data2(length(data2)+1)=-1-i;
                        %-1-i marks "not used" peaks, string in field, i.e. 'not used'
                    end
                else
                    if isequalwithequalnans(data2tmp{1},NaN)
                        data2(length(data2)+1)=-2-i;
                        %-2-i marks a new compound, no entry in field
                    else
                        data2(length(data2)+1)=data2tmp{1};
                    end
                end
            end
        %end
        end
    end
    clear integralraw data1tmp data2tmp;
    %t=toc;
    %fprintf('Done in %g seconds.\n',t);
end
if ishandle(waitbar_progress)
    waitbar(4/7,waitbar_progress,'Calculating concentrations...')
end
%fprintf('Calculating concentrations... ');
%tic;
totallinecount=1;
samplenumber=0;
ValuesTitlerow(1)={''};
ValuesTitlerow(1)=[];
Intermediatevalues=0;
Intermediatevaluesuncorrected=0;
Numberusedpeaks={'(0/0)'};
Quotientusedpeaks=0;
while totallinecount<length(data1)
    %read all data of one spectrum
    datarow=1;
    Singlevalues=zeros(30,1000);
    clear('data1a');
    data1a(1)={''};
    data1a(1)=[];
    data2a=[];
    data1a{datarow}=data1{totallinecount};
    data2a(datarow)=data2(totallinecount);
    endreached=0;
    title1= strtrim(strrep(data1a(datarow),'title:',''));
    samplenumber=samplenumber+1;
    ValuesTitlerow(samplenumber)=title1;
    %read data until the next spectrum starts or the file ends 
    while endreached == 0
        datarow=datarow+1;
        totallinecount=totallinecount+1;
        if totallinecount <= length(data1)&&datarow<=length(data1)
            %if data2(datarow)==-3-i%new spectrum identified by -3-i
            if data2(totallinecount)==-3-i%new spectrum identified by -3-i
                endreached=1;
            else
                data1a{datarow}=data1{totallinecount};
                data2a(datarow)=data2(totallinecount);
            end
        else
            endreached=1;
        end
    end
    Compoundnumber=0;
    i_Compoundnumber=1;
    %scale to reference substance integral
    if scale2refsubst==1
        %search for reference substance
        i_refsubst=1;
        while ~(strcmp(refsubstname,data1a(i_refsubst))==1&&data2a(i_refsubst)==-2-i)
            i_refsubst=i_refsubst+1;
            if (i_refsubst+1)>length(data1a)||(i_refsubst+1)>length(data2a)
                msgbox(sprintf('Reference substance %s not found.',refsubstname),'Error','error');
                %fprintf('\nReference substance %s not found.\n',refsubstname);
                %set(hObject,'Enable','on');
                if ishandle(waitbar_progress)
                    close(waitbar_progress)
                end
                return;
            end
        end
        i_refsubst=i_refsubst+1;%find the first peak that contains values
        while ~(data2a(i_refsubst)<0||data2a(i_refsubst)>=0)
            i_refsubst=i_refsubst+1;
        end
        %if data2a(i_refsubst)>0
        if isreal(data2a(i_refsubst))
            refsubstintegral=data2a(i_refsubst);
        else
            msgbox(sprintf('No peak integral of the reference substance %s found.',refsubstname),'Error','error');
            %fprintf('\nNo peak of the reference substance %s found.\n',...
            %    refsubstname);
            %set(hObject,'Enable','on');
            if ishandle(waitbar_progress)
                close(waitbar_progress)
            end
            return
        end
        for j_ref=1:length(data2a)%divide all values through the reference value
            %if data2a(j_ref)>0
            if isreal(data2a(j_ref))
                data2a(j_ref)=data2a(j_ref)/refsubstintegral;
            end
        end
    end
    %divide by correction factors
    while i_Compoundnumber<datarow%i_Compoundnumber<length(data2a)&&i_Compoundnumber<datarow
        %new compound identified by -2
        if data2a(i_Compoundnumber)==-2-i
            %a flag to see if a compound was not found in the peak
            %information file
            compound_found=1;
            Compoundnumber=Compoundnumber+1;
            ValuesTitlecolumn(Compoundnumber+1,1)=strtrim(data1a(i_Compoundnumber));
            %ValuesTitlecolumn(:,1)
            %check whether the compounds have the same order in all samples
            Compoundnumber_correct=Compoundnumber;
            %if samplenumber>1
            if samplenumber==1
                ValuesTitlecolumn_total(Compoundnumber+1,1)=ValuesTitlecolumn(Compoundnumber+1,1);
            else
                %if(length(ValuesTitlecolumn_total(:,1))<=Compoundnumber+1)
                %    length(ValuesTitlecolumn_total(:,1))
                if ~(strcmp(ValuesTitlecolumn(Compoundnumber+1,1),ValuesTitlecolumn_total(Compoundnumber+1,1)))
                   switchedvaluesfound=0;%flag
                   for j1=1:(length(ValuesTitlecolumn_total)-1)
                       if strcmp(ValuesTitlecolumn(Compoundnumber+1,1),ValuesTitlecolumn_total(j1+1,1))
                           Compoundnumber_correct=j1;
                           switchedvaluesfound=1;
                           ValuesTitlecolumn(j1+1,1)=ValuesTitlecolumn(Compoundnumber+1,1);
                           ValuesTitlecolumn(Compoundnumber+1,1)={''};
                           %else
                           %Compoundnumber_correct=Compoundnumber;
                       end
                   end
                   %msgbox(sprintf('Please make sure that the compounds in the integral file have the same order (Sample %s, Compound %s).',ValuesTitlerow{samplenumber},ValuesTitlecolumn{Compoundnumber+1,1}),'Error','error');
                    %try
                    %    close(waitbar_progress)
                    %end
                    %return
                %end
                %else
                if switchedvaluesfound==0
                    %msgbox(sprintf('Please make sure that the compound %s is present in the first sample.',ValuesTitlecolumn{Compoundnumber+1,1}),'Error','error');
                    ValuesTitlecolumn_total(length(ValuesTitlecolumn_total(:,1))+1,1)=ValuesTitlecolumn(Compoundnumber+1,1);
                    %ValuesTitlecolumn(length(ValuesTitlecolumn(:,1))+1,1)=ValuesTitlecolumn(Compoundnumber+1,1);
                    Compoundnumber_correct=length(ValuesTitlecolumn_total(:,1))-1;
                    Values(length(Values(:,1))+1,1)=0;%Add entries of the new compound of all earlier samples (Matlab automatically fills all previous samples with 0, not only the first one! 
                    Valuesuncorrected(length(Valuesuncorrected(:,1))+1,1)=0;
                    length_numberusedpeaks=length(Numberusedpeaksintotal(:,1));
                    for i_numberusedpeaks=1:length(Numberusedpeaksintotal(1,:))
                        Numberusedpeaksintotal(length_numberusedpeaks+1,i_numberusedpeaks)={'(0/0)'};
                    end
                    clear('length_numberusedpeaks');
                    Quotientusedpeaksintotal(length(Quotientusedpeaksintotal(:,1))+1,1)=0;
                    %try
                    %    close(waitbar_progress)
                    %end
                    %return
                end
                end
            end
            %search correction factors for matching metabolite
            if no_calibrationfactors==1
                i_calibfactor=1;
                while strcmp(calibfactortext(i_calibfactor,1),...
                        ValuesTitlecolumn_total(Compoundnumber_correct+1,1))==0
                    i_calibfactor=i_calibfactor+1;
                    if (i_calibfactor+1)>length(calibfactortext)
                        msgbox(sprintf('Sample %s: Peak information not found for compound %s.',...
                            title1{1},ValuesTitlecolumn_total{Compoundnumber_correct+1,1}),'Warning','warn');
                        %fprintf('\nSample %s: Peak information not found for compound %s.\n',...
                        %    title1{1},ValuesTitlecolumn{Compoundnumber+1,1});
                        errorlist{length(errorlist)+1}=['Sample ',title1{1},...
                            ': Peak information not found for compound ',...
                            ValuesTitlecolumn_total{Compoundnumber_correct+1,1},'.'];
                        compound_found=0;
                        break;
                        %return;
                    end
                end
            end
            i_Compoundnumber=i_Compoundnumber+1;
           if compound_found==1
            i_Peaknumber=0;
            special_rule=0;
            usedpeaks=0;
            unusedpeaks=0;
            %how many peaks are used for quantifying?
            if no_calibrationfactors==1
                i_quantsearch=i_calibfactor;
                quantsearch_number(Compoundnumber_correct)=0;
                %number of protons for this peak for reliability estimation
                protoncount=[];
                protoncount_used=[];
                protoncount_notused=[];
                while (calibfactor(i_quantsearch,3)<=0||...
                        calibfactor(i_quantsearch,3)>0)&&i_quantsearch<length(calibfactor(:,1))
                    if ~(calibfactor(i_quantsearch,3)==0)
                        quantsearch_number(Compoundnumber_correct)=quantsearch_number(...
                            Compoundnumber_correct)+1;
                    end
                    i_quantsearch=i_quantsearch+1;
                end
            end
            %calculate concentrations for each peak
            nextcompoundreached=0;
            if i_Compoundnumber<=length(data1a)
            while nextcompoundreached==0
                %if data2a(i_Compoundnumber)>=0%~='not used  '
                if isreal(data2a(i_Compoundnumber))
                    i_Peaknumber=i_Peaknumber+1;
                    peaktitle=data1a(i_Compoundnumber);
                    %search matching peaktitle
                    i_peaktitle=1;
                    if no_calibrationfactors==1
                        while strcmp(strtrim(calibfactortext((i_calibfactor+i_peaktitle),1)),peaktitle)==0
                            %start of next compound indicated by NaN
                            if (i_calibfactor+i_peaktitle)<=length(calibfactor(:,3))
                                if calibfactor(i_calibfactor+i_peaktitle,3)>=0||calibfactor(i_calibfactor+i_peaktitle,3)<0
                                    i_peaktitle=i_peaktitle+1;
                                else
                                    msgbox(sprintf('Peak %s of compound %s not found in file %s. \n',...
                                        peaktitle{1},ValuesTitlecolumn_total{Compoundnumber_correct+1,1},calibrationfactorsfile),...
                                        'Warning','warn');
                                    %fprintf('\nPeak %s of compound %s not found in file %s. \n',...
                                    %    peaktitle{1},ValuesTitlecolumn{Compoundnumber+1,1},calibrationfactorsfile);
                                    return;
                                end
                            else
                                msgbox(sprintf('Peak %s of compound %s not found in file %s. \n',...
                                    peaktitle{1},ValuesTitlecolumn_total{Compoundnumber_correct+1,1},calibrationfactorsfile),...
                                    'Error','error');
                                %fprintf('\nPeak %s of compound %s not found in file %s. \n',...
                                %    peaktitle{1},ValuesTitlecolumn{Compoundnumber+1,1},calibrationfactorsfile);
                                if ishandle(waitbar_progress)
                                    close(waitbar_progress)
                                end
                                return;
                            end
                        end
                        Singlevalues(i_Peaknumber,Compoundnumber_correct)=data2a(i_Compoundnumber)*refsubstanceconcentration*spikeinfactor/(calibfactor(i_calibfactor+i_peaktitle-1,3));%*referencefactor(tsptype));
                        %count peaks unequal to 0 for reliability check
                        if ~(calibfactor(i_calibfactor+i_peaktitle-1,3)==0)
                            protoncount(i_Peaknumber)=calibfactor(i_calibfactor+i_peaktitle-1,2);
                            %if Singlevalues(i_Peaknumber,Compoundnumber)>0
                            if ~(Singlevalues(i_Peaknumber,Compoundnumber_correct)==0)
                            %if isreal(Singlevalues(i_Peaknumber,Compoundnumber))
                                protoncount_used(length(protoncount_used)+1)=i_Peaknumber;
                                usedpeaks=usedpeaks+1;
                            else
                                protoncount_notused(length(protoncount_notused)+1)=i_Peaknumber;
                                unusedpeaks=unusedpeaks+1;
                            end
                        end
                        %certain peaks have to be present to quantify the compound:
                        if Singlevalues(i_Peaknumber,Compoundnumber_correct)==0%&&calibfactor(i_calibfactor+i_peaktitle-1,1)==1
                            special_rule=1;
                        end
                    else
                        Singlevalues(i_Peaknumber,Compoundnumber_correct)=data2a(i_Compoundnumber)*refsubstanceconcentration*spikeinfactor;
                        %if Singlevalues(i_Peaknumber,Compoundnumber)>0
                        if ~(Singlevalues(i_Peaknumber,Compoundnumber_correct)==0)
                            usedpeaks=usedpeaks+1;
                        else
                            unusedpeaks=unusedpeaks+1;
                        end
                    end
                end
                if i_Compoundnumber+1<=length(data1a)
                    i_Compoundnumber=i_Compoundnumber+1;
                    if ~isreal(data2a(i_Compoundnumber))&&data2a(i_Compoundnumber)<-1
                    %if data2a(i_Compoundnumber)<-1
                        nextcompoundreached=1;
                    end
                else
                    nextcompoundreached=1;
                end
            end
            end
            %are there enough values for a reliable quantification?
            quantsearch_number(Compoundnumber_correct)=usedpeaks+unusedpeaks;
            if usedpeaks>0
                Quotientfoundpeaks(Compoundnumber_correct,samplenumber)=usedpeaks/(usedpeaks+unusedpeaks);
                if usedpeaks/(usedpeaks+unusedpeaks)<Peakthreshold&&(usedpeaks+unusedpeaks)>0
                  if singlepeaksmissingallowed==1&&unusedpeaks==1
                      %do nothing if only one peak is missing and single
                      %missing peaks are allowed
                  else
                    numberpeakcountlowerthanthreshold=numberpeakcountlowerthanthreshold+1;
                    if no_calibrationfactors==1%peak probability checking
                        if max(protoncount(protoncount_notused))>=max(protoncount(protoncount_used))
                            Singlevalues(:,Compoundnumber_correct)=0;
                            numberpeakcountlowerthanthresholdexcluded=numberpeakcountlowerthanthresholdexcluded+1;
                        end
                    else
                        Singlevalues(:,Compoundnumber_correct)=0;
                        numberpeakcountlowerthanthresholdexcluded=numberpeakcountlowerthanthresholdexcluded+1;
                    end
                  end
                end
            else
                Quotientfoundpeaks(Compoundnumber_correct,samplenumber)=NaN;
            end
            %set compounds where an obligatory peak is missing to zero
            if no_calibrationfactors==1
                if special_rule==1
                    Singlevalues(:,Compoundnumber_correct)=0;
                    special_rule=0;
                    Obligatorypeakmissing=Obligatorypeakmissing+1;
                end
            end
           end %end check if a compund is in the peak information file
        %end
        %if data2a(i_Compoundnumber)==-2-i
        else
            i_Compoundnumber=i_Compoundnumber+1;
        end
    end
    %calculate the means
    %clear('Intermediatevalues');
    for i_intermediate=1:length(Intermediatevalues)
        Intermediatevalues(i_intermediate)=0;
    end
    for i_intermediate=1:length(Intermediatevaluesuncorrected)
        Intermediatevaluesuncorrected(i_intermediate)=0;
    end
    for i_intermediate=1:length(Numberusedpeaks)
        Numberusedpeaks(i_intermediate)={'(0/0)'};
    end
    for i_intermediate=1:length(Quotientusedpeaks)
        Quotientusedpeaks(i_intermediate)=0;
    end
    for j=1:(length(ValuesTitlecolumn_total)-1)
%    for j=1:Compoundnumber
    %for j=1:Compoundnumber_correct
        Singlevector=[];
        Intermediatesum=0;
        Intermediatevaluecount=0;
        Toomanyoutliers=0;
        Outliers=0;
        Singlevectororiginal=[];
        for i1=1:15
            %if Singlevalues(i1,j)>0
            if ~(Singlevalues(i1,j)==0)
                Intermediatesum=Intermediatesum+Singlevalues(i1,j);
                Singlevector(length(Singlevector)+1)=Singlevalues(i1,j);
                Intermediatevaluecount=Intermediatevaluecount+1;
            end
        end
        if Intermediatevaluecount==0
            Intermediatevalues(j)=0;
            %save number of peaks used for quantification as a quality marker
            if j<=length(quantsearch_number)
                Numberusedpeaks{j}=strcat('(0/',num2str(quantsearch_number(j)),')');
            else
                Numberusedpeaks{j}='(0/0)';
                %peak infos were missing for some compounds
            end
            Quotientusedpeaks(j)=0;
        end
        if Intermediatevaluecount==1
            Intermediatevalues(j)=Intermediatesum;
            if j<=length(quantsearch_number)
                Numberusedpeaks{j}=strcat('(1/',num2str(quantsearch_number(j)),')');
                Quotientusedpeaks(j)=1/quantsearch_number(j);
            else
                Numberusedpeaks{j}='(1/0)';
                Quotientusedpeaks(j)=0;
            end
        end
        if Intermediatevaluecount>1
            Meanvalue=mean(Singlevector);
            %identify outliers
            Singlevectorwithoutoutliers=[];
            for k=1:length(Singlevector)
                if Singlevector(k)/median(Singlevector)>(1-Outliervalue)&&Singlevector(k)/...
                        median(Singlevector)<(1+Outliervalue)
                    Singlevectorwithoutoutliers(length(Singlevectorwithoutoutliers)+1)...
                    =Singlevector(k);
                else
                    Outliers=1;
                end
            end
            if length(Singlevectorwithoutoutliers)<2
                Toomanyoutliers=1;
                Singlevectorwithoutoutliers=Singlevector;
            end
            Singlevectororiginal=Singlevector;
            Singlevector=Singlevectorwithoutoutliers;
            Meanvalue=mean(Singlevector);
            if j<=length(quantsearch_number)
                Numberusedpeaks{j}=strcat('(',num2str(length(Singlevector)),'/',num2str(quantsearch_number(j)),')');
                Quotientusedpeaks(j)=length(Singlevector)/quantsearch_number(j);
            else
                Numberusedpeaks{j}=strcat('(',num2str(length(Singlevector)),'/0)');
                Quotientusedpeaks(j)=0;
            end
            %choose median (or lowest) if SD is too high 
            if Toomanyoutliers==1
                if length(Singlevector)==2
                    Intermediatevalues(j)=min(Singlevector);
                end
                if length(Singlevector)>2
                    Intermediatevalues(j)=median(Singlevector);
                end
                Outliers=0;%avoid double counting
                NumberOutliers=NumberOutliers+1;
                Outlierslist(length(Outlierslist(:,1))+1,:)=...
                    {ValuesTitlerow{samplenumber} ValuesTitlecolumn_total{j+1}...
                    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0};
                i1=1;
                while i1<=length(Singlevector)
                    if i1<=(length(Outlierslist(1,:))-2)
                        Outlierslist(length(Outlierslist(:,1)),i1+2)={Singlevector(i1)};
                    end
                    i1=i1+1;
                end
            else
                Intermediatevalues(j)=Meanvalue;
            end
            %save outliers
            if Outliers==1
                NumberOutliers=NumberOutliers+1;
                Outlierslist(length(Outlierslist(:,1))+1,:)=...
                    {ValuesTitlerow{samplenumber} ValuesTitlecolumn_total{j+1}...
                    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0};
                i1=1;
                while i1<=length(Singlevectororiginal)
                    if i1<=(length(Outlierslist(1,:))-2)
                        Outlierslist(length(Outlierslist(:,1)),i1+2)=...
                            {Singlevectororiginal(i1)};
                    end
                    i1=i1+1;
                end
            end
        end
        Intermediatevaluesuncorrected(j)=Intermediatevalues(j);
        %above LLOQ?                
        %search LLOQs for matching metabolite
        if dontuse_LLOQS==1
            i_LLOQ=1;
            LLOQnotfound=0;
            while strcmp(LLOQtext(i_LLOQ),ValuesTitlecolumn_total(j+1,1))==0
                i_LLOQ=i_LLOQ+1;
                if i_LLOQ>length(LLOQtext)
                    %show warning only once
                    if LLOQnotfound_warning==0
                        LLOQnotfound_warning=1;
                        msgbox(sprintf('\nSample %s: LLOQ not found for compound %s.\n',...
                            title1{1},ValuesTitlecolumn_total{j+1,1}),'Warning','warn');
                    end
                    %fprintf('\nSample %s: LLOQ not found for compound %s.\n',...
                    %    title1{1},ValuesTitlecolumn{j+1,1});
                    LLOQnotfound=1;
                    errorlist{length(errorlist)+1}=['Sample ',title1{1},...
                        ': LLOQ not found for compound ',ValuesTitlecolumn_total{j+1,1},'.'];
                    break;
                    %return;
                end
            end
            if LLOQnotfound==0
                if abs(Intermediatevalues(j))<LLOQ(i_LLOQ)&&abs(Intermediatevalues(j))>0
                    NumberbelowLLOQ=NumberbelowLLOQ+1;
                    Intermediatevalues(j)=0;
                end
            end
        end
    end
    if samplenumber>1
        Values(:,samplenumber)=Intermediatevalues(:);
    else
        Values(:,samplenumber)=Intermediatevalues(:);
    end
    Valuesuncorrected(:,samplenumber)=Intermediatevaluesuncorrected(:);
    Numberusedpeaksintotal(:,samplenumber)=Numberusedpeaks(:);
    Quotientusedpeaksintotal(:,samplenumber)=Quotientusedpeaks(:);
    %if samplenumber==1
    %    ValuesTitlecolumn_total=ValuesTitlecolumn;
    %end
end
%t=toc;
%fprintf('Done in %g seconds.\n',t);
pause(0.075);%pause for a small time to let windows redraw
%multiply with correction factor from spike-in-experiment
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%Fehler sptestens hier (mai2012) 
if ishandle(waitbar_progress)
    waitbar(5/7,waitbar_progress,'Normalizing and correcting data...')
end
Values=Values*dilutionfactor;
%Calculate means if there are several measurements of the same sample
if mean_calculation==1%1 if a checkmark is set
    %fprintf('Calculating means for duplicate samples... ');
    %tic;
    i_MEANmeasurements1=1;
    length_1=length(Values(:,1));
    TEMsum(1:length_1)=0;
    TEMcount(1:length_1)=0;
    ValuesMEANdiscard=[];
    i_MEAN=0;
    while i_MEANmeasurements1<=length(ValuesTitlerow)%all samples
        i_MEANmeasurements2=1; 
        %multiple measurements have to start with '*a', then '*b' etc.
        length_1valuestitlerow=length(ValuesTitlerow{i_MEANmeasurements1});
        if length_1valuestitlerow>0
        if ValuesTitlerow{i_MEANmeasurements1}(length_1valuestitlerow)=='a'
            i_MEANrows=[];
            i_MEANcount=1;
            i_MEANrows(i_MEANcount)=i_MEANmeasurements1;
            while i_MEANmeasurements2<=length(ValuesTitlerow)
                if i_MEANmeasurements1~=i_MEANmeasurements2
                    if strncmp(ValuesTitlerow{i_MEANmeasurements1},ValuesTitlerow{i_MEANmeasurements2},...
                            length_1valuestitlerow-1)==1&&length(ValuesTitlerow{i_MEANmeasurements1})==...
                            length(ValuesTitlerow{i_MEANmeasurements2})
                        i_MEANcount=i_MEANcount+1;
                        i_MEANrows(i_MEANcount)=i_MEANmeasurements2;
                    end
                end
                i_MEANmeasurements2=i_MEANmeasurements2+1;
            end
            if i_MEANcount>1
                i_MEAN=i_MEAN+1;%number of found replicate spectra
                ValuesTitlerowMEAN{i_MEAN}=ValuesTitlerow{i_MEANmeasurements1}(1:length_1valuestitlerow-1);
                MEANintermediatevalue=0;
                i_MEANintermediatevalue=0;
                for i_MEANsinglecompound=1:length(Values(:,1))%all compounds
                    for i_MEANsinglesample=1:i_MEANcount
                        if Values(i_MEANsinglecompound,i_MEANrows(i_MEANsinglesample))~=0
                            MEANintermediatevalue=MEANintermediatevalue+Values(i_MEANsinglecompound,i_MEANrows(i_MEANsinglesample));
                            %Technical Error of Measurement
                            i_MEANintermediatevalue=i_MEANintermediatevalue+1;
                            if i_MEANintermediatevalue==1
                                technicalerror=Values(i_MEANsinglecompound,i_MEANrows(i_MEANsinglesample));
                            end
                            if i_MEANintermediatevalue==2
                                technicalerror=(technicalerror-Values(i_MEANsinglecompound,i_MEANrows(i_MEANsinglesample)))^2;
                            end
                        end
                    end
                    if i_MEANintermediatevalue>1
                        ValuesMEAN(i_MEANsinglecompound,i_MEAN)=MEANintermediatevalue/i_MEANintermediatevalue;
                        ValuesMEANdiscard(i_MEANsinglecompound,i_MEAN)=MEANintermediatevalue/i_MEANintermediatevalue;
                         ValuesTEM(i_MEANsinglecompound,i_MEAN)=technicalerror;
                        TEMsum(i_MEANsinglecompound)=TEMsum(i_MEANsinglecompound)+technicalerror;
                        TEMcount(i_MEANsinglecompound)=TEMcount(i_MEANsinglecompound)+1;
                    else
                        if i_MEANintermediatevalue>0
                            ValuesMEAN(i_MEANsinglecompound,i_MEAN)=Values(i_MEANsinglecompound,i_MEANrows(i_MEANsinglesample));
                            ValuesMEANdiscard(i_MEANsinglecompound,i_MEAN)=0;
                             ValuesTEM(i_MEANsinglecompound,i_MEAN)=0;
                        else
                            ValuesMEAN(i_MEANsinglecompound,i_MEAN)=0;
                            ValuesMEANdiscard(i_MEANsinglecompound,i_MEAN)=0;
                             ValuesTEM(i_MEANsinglecompound,i_MEAN)=0;
                        end
                    end
                    MEANintermediatevalue=0;
                    i_MEANintermediatevalue=0;
                end
            end
        end
        end
        i_MEANmeasurements1=i_MEANmeasurements1+1;
    end
    TEM(1:length(TEMcount))=NaN;
    for i_TEM=1:length(TEMcount)
        if TEMcount(i_TEM)>0
            TEM(i_TEM)=sqrt(TEMsum(i_TEM)/(2*TEMcount(i_TEM)));
        %else
        %    TEM(i_TEM)=NaN;
        end
    end
    length_1Values=length(Values(1,:));
    if (i_MEAN>0)&&(not(isempty(ValuesMEANdiscard)))
        meanvaluesdiscard=mean(ValuesMEANdiscard');
        standarddeviationdiscard=std(ValuesMEANdiscard');
        minimumValuesMEANdiscard=min(ValuesMEANdiscard');
        maximumValuesMEANdiscard=max(ValuesMEANdiscard');
        length_1ValuesMEANdiscard=length(ValuesMEANdiscard);
        %list without '0'
        for i1=1:length(ValuesMEANdiscard(:,1))
            for j=1:length(ValuesMEANdiscard(1,:))
                if ValuesMEANdiscard(i1,j)==0
                    ValuesMEANdiscardwithout0(i1,j)=NaN;
                else
                    ValuesMEANdiscardwithout0(i1,j)=ValuesMEANdiscard(i1,j);
                end
            end
        end
        meanvaluesdiscardwithout0=[];
        standarddeviationdiscardwithout0=[];
        minimumValuesMEANdiscardwithout0=[];
        maximumValuesMEANdiscardwithout0=[];
        %means without '0'
        for i1=1:length(ValuesMEANdiscard(:,1))%all compounds
            MEANMEANdiscardwithout0=[];
            i_MEANMEANdiscardwithout0=0;
            for j=1:length(ValuesMEANdiscard(1,:))
                if ValuesMEANdiscard(i1,j)~=0
                    i_MEANMEANdiscardwithout0=i_MEANMEANdiscardwithout0+1;
                    MEANMEANdiscardwithout0(i_MEANMEANdiscardwithout0)=ValuesMEANdiscard(i1,j);
                end
            end
            if i_MEANMEANdiscardwithout0>0
                meanvaluesdiscardwithout0(i1)=mean(MEANMEANdiscardwithout0);
                standarddeviationdiscardwithout0(i1)=std(MEANMEANdiscardwithout0);
                minimumValuesMEANdiscardwithout0(i1)=min(MEANMEANdiscardwithout0);
                maximumValuesMEANdiscardwithout0(i1)=max(MEANMEANdiscardwithout0);
            else
                meanvaluesdiscardwithout0(i1)=NaN;
                standarddeviationdiscardwithout0(i1)=NaN;
                minimumValuesMEANdiscardwithout0(i1)=NaN;
                maximumValuesMEANdiscardwithout0(i1)=NaN;
            end
        end
        length_1titlerowMEAN=length(ValuesTitlerowMEAN);
        ValuesMEANdiscardwithout0(:,length_1titlerowMEAN+1)=meanvaluesdiscardwithout0;
        ValuesMEANdiscardwithout0(:,length_1titlerowMEAN+2)=standarddeviationdiscardwithout0;
        ValuesMEANdiscardwithout0(:,length_1titlerowMEAN+3)=TEM;
        ValuesMEANdiscardwithout0(:,length_1titlerowMEAN+4)=TEM./meanvaluesdiscardwithout0*100;
        ValuesMEANdiscardwithout0(:,length_1titlerowMEAN+5)=1-(TEM.*TEM./(standarddeviationdiscardwithout0.*standarddeviationdiscardwithout0));
        ValuesMEANdiscardwithout0(:,length_1titlerowMEAN+6)=minimumValuesMEANdiscardwithout0;
        ValuesMEANdiscardwithout0(:,length_1titlerowMEAN+7)=maximumValuesMEANdiscardwithout0;
        ValuesMEANdiscardwithout0(:,length_1titlerowMEAN+8)=TEMcount;
        %
        ValuesMEANdiscard(:,length_1titlerowMEAN+1)=meanvaluesdiscard;
        ValuesMEANdiscard(:,length_1titlerowMEAN+2)=standarddeviationdiscard;
        ValuesMEANdiscard(:,length_1titlerowMEAN+3)=TEM;
        ValuesMEANdiscard(:,length_1titlerowMEAN+4)=TEM./meanvaluesdiscard*100;
        ValuesMEANdiscard(:,length_1titlerowMEAN+5)=1-(TEM.*TEM./(standarddeviationdiscard.*standarddeviationdiscard));
        ValuesMEANdiscard(:,length_1titlerowMEAN+6)=minimumValuesMEANdiscard;
        ValuesMEANdiscard(:,length_1titlerowMEAN+7)=maximumValuesMEANdiscard;
        ValuesMEANdiscard(:,length_1titlerowMEAN+8)=TEMcount;
        ValuesTitlerowMEAN(length_1titlerowMEAN+1)={'z1 Mean'};
        ValuesTitlerowMEAN(length_1titlerowMEAN+2)={'z2 Standard deviation'};
        ValuesTitlerowMEAN(length_1titlerowMEAN+3)={'z3 Technical error (absolute)'};
        ValuesTitlerowMEAN(length_1titlerowMEAN+4)={'z4 Technical error [%]'};
        ValuesTitlerowMEAN(length_1titlerowMEAN+5)={'z5 Coefficient of reliability R'};
        ValuesTitlerowMEAN(length_1titlerowMEAN+6)={'z6 Minimum'};
        ValuesTitlerowMEAN(length_1titlerowMEAN+7)={'z7 Maximum'};
        ValuesTitlerowMEAN(length_1titlerowMEAN+8)={'z8 Number of values'};
    end
    %t=toc;
    %fprintf('Done in %g seconds.\n',t);
end%end calculation of means of repeated measurements
length_1titlerow=length(ValuesTitlerow);
pause(0.075);%pause for a small time to let windows redraw
%Values without 0
for i1=1:length(Values(:,1))
    for j=1:length(Values(1,:))
        if Values(i1,j)==0
            Valueswithout0(i1,j)=NaN;
        else
            Valueswithout0(i1,j)=Values(i1,j);
        end
    end
end
meanvalueswithout0=[];
standarddeviationwithout0=[];
minimumValueswithout0=[];
maximumValueswithout0=[];
%means without '0'
for i1=1:length(Values(:,1))%all compounds
    awithout0=[];
    i_without0=0;
    Numberwithout0(i1)=0;
    for j=1:length(Values(1,:))
        if Values(i1,j)~=0
            i_without0=i_without0+1;
            awithout0(i_without0)=Values(i1,j);
            Numberwithout0(i1)=Numberwithout0(i1)+1;
        end
    end        
    %means, max and min only for values >0
    abigger0=[];
    i_bigger0=0;
    Numberbigger0(i1)=0;
    for j=1:length(Values(1,:))
        if Values(i1,j)>0
            i_bigger0=i_bigger0+1;
            abigger0(i_bigger0)=Values(i1,j);
            Numberbigger0(i1)=Numberbigger0(i1)+1;
        end
    end
    if i_bigger0>0
        meanvalueswithout0(i1)=mean(abigger0);
        standarddeviationwithout0(i1)=std(abigger0);
        minimumValueswithout0(i1)=min(abigger0);
        maximumValueswithout0(i1)=max(abigger0);
    else
        meanvalueswithout0(i1)=NaN;
        standarddeviationwithout0(i1)=NaN;
        minimumValueswithout0(i1)=NaN;
        maximumValueswithout0(i1)=NaN;
    end
end
Valueswithout0(:,length_1titlerow+1)=meanvalueswithout0;
Valueswithout0(:,length_1titlerow+2)=standarddeviationwithout0;
Valueswithout0(:,length_1titlerow+3)=minimumValueswithout0;
Valueswithout0(:,length_1titlerow+4)=maximumValueswithout0;
Valueswithout0(:,length_1titlerow+5)=Numberbigger0;
ValuesTitlerowplusextra=ValuesTitlerow;
ValuesTitlerowplusextra(length_1titlerow+1)={'z1 Mean'};
ValuesTitlerowplusextra(length_1titlerow+2)={'z2 Standard deviation'};
ValuesTitlerowplusextra(length_1titlerow+3)={'z3 Minimum'};
ValuesTitlerowplusextra(length_1titlerow+4)={'z4 Maximum'};
ValuesTitlerowplusextra(length_1titlerow+5)={'z5 Number of values'};
%new headline for "used peaks" spreadsheet
ValuesTitlecolumnnew_total{1}=ValuesTitlecolumn_total{1};
for i1=2:length(ValuesTitlecolumn_total)
    ValuesTitlecolumnnew_total{2*(i1-1)+1}=ValuesTitlecolumn_total{i1};
    ValuesTitlecolumnnew_total{2*(i1-1)}=ValuesTitlecolumn_total{i1};
end
if crea_correction==1
    creatinineexist=0;%if creatinine is quantified, normalize on creatinine!
    for i1=1:length(ValuesTitlecolumn_total)
        if strcmp(ValuesTitlecolumn_total{i1},crea_correction_compound)
            creatinine_nr=i1-1;
            creatinineexist=1;
        end
    end
    Crea_Count=0;
    if creatinineexist==1
        %fprintf('Normalizing on %s... ',crea_correction_compound);
        %tic;
        for i1=1:(length(Valueswithout0(1,:))-5)
            ValuesCrea(:,i1)=Valueswithout0(:,i1)/Valueswithout0(creatinine_nr,i1);
            Crea_Count=Crea_Count+Values(creatinine_nr,i1);
        end
        %t=toc;
        %fprintf('Done in %g seconds.\n',t);
    end
end
pause(0.075);%pause for a small time to let windows redraw
if dil_correction==1
    dfexist=0;%if dilution factors are given, normalize on them!
    df(1:length(ValuesTitlerow))=1;
    for i1=1:length(ValuesTitlerow)
        titlepart=ValuesTitlerow{i1};
        titlelength=length(titlepart);
        if titlelength>6
            titlepart(1:titlelength-6)=[];
            if strncmp(titlepart,'df',2)==1
                titlepart(1:2)=[];
                df_temp=str2num(titlepart);
                %if length(df_temp)>0
                if not(isempty(df_temp))
                    df(i1)=df_temp;
                    dfexist=1;
                end
            end
        end
    end
    if dfexist==1
        %fprintf('Correcting for dilution... ');
        %tic;
        for i1=1:length(ValuesTitlerow)
            Valuesdf(:,i1)=Valueswithout0(:,i1)*df(i1);
        end
        %t=toc;
        %fprintf('Done in %g seconds.\n',t);
    else
        msgbox(sprintf('Dilution correction was selected but no dilution factors were found!'),...
                                        'Warning','warn');
        errorlist{length(errorlist)+1}='Dilution correction was selected but no dilution factors were found!';
    end
end
%create a cell array that contains the values and the number of used peaks
%for each value
Used_peaks_string={''};
Used_peaks_string2={''};

for i1=1:length(ValuesTitlecolumnnew_total)
    Used_peaks_string(1,i1)=ValuesTitlecolumnnew_total(i1);
    Used_peaks_string2(1,i1)=ValuesTitlecolumnnew_total(i1);
end
for i1=1:length(ValuesTitlerow)
    Used_peaks_string(i1+1,1)=ValuesTitlerow(i1);
    Used_peaks_string2(i1+1,1)=ValuesTitlerow(i1);
     if i1<=length(Numberusedpeaksintotal(1,:))
         for j=1:length(Valueswithout0(:,1))
             if isequalwithequalnans(Valueswithout0(j,i1),NaN)
                 Used_peaks_string(i1+1,2*j)={'0'};
                 Used_peaks_string2{i1+1,2*j}=0;
             else
                 Used_peaks_string(i1+1,2*j)={num2str(Valueswithout0(j,i1))};
                 Used_peaks_string2{i1+1,2*j}=Valueswithout0(j,i1);
             end
             Used_peaks_string(i1+1,2*j+1)=(Numberusedpeaksintotal(j,i1));
             Used_peaks_string2(i1+1,2*j+1)=(Numberusedpeaksintotal(j,i1));
         end
     end
end

switch inputfile_id
    case 1
        input_filetype='AMIX text';
        xls_integralsheet='Not used';
        xls_integralarea='Not used';
    case 2
        input_filetype='Text';
        xls_integralsheet='Not used';
        xls_integralarea='Not used';
    case 3
        input_filetype='Excel';
end

switch LLOQ_id
    case 1
        LLOQ_filetype='Excel';
    case 2
        LLOQ_filetype='Text';
        LLOQpage='Not used';
        LLOQrange='Not used';
end

switch corr_id
    case 1
        corr_filetype='Excel';
    case 2
        corr_filetype='Text';
        calibrationfilepage='Not used';
        calibrationfilearea='Not used';
end

switch output_id
    case 1
        output_filetype='Excel';
    case 2
        output_filetype='Text';
end

switch dil_correction
    case 0
        dilution_choice='No';
    case 1
        dilution_choice='Yes';
end

switch mean_calculation
    case 0
         means_choice='No';
    case 1
         means_choice='Yes';
end

switch singlepeaksmissingallowed
    case 0
        singlepeaksmissingallowed_choice='No';
    case 1
        singlepeaksmissingallowed_choice='Yes';
end

Configuration_titles={'User information:','Date and time','User name',...
    'Computer name','Operating system','Matlab version','Configuration:','QUANTIFY version',...
    'Peak integral file name','Peak integral file type','Peak integral file Excel spreadsheet',...
    'Peak integral file Excel range',...
    'Peak information file name','Peak information file type','Peak information Excel spreadsheet',...
    'Peak information file Excel range','LLOQ file name','LLOQ file type','LLOQ file Excel spreadsheet','LLOQ file Excel range',...
    'Correction factor','Dilution factor','Outlier threshold','Peak threshold','Allow single missing peaks','Scale to',...
    'Reference concentration','Normalize to','Dilution correction','Calculate means for replicates',...
    'Output file','Output file type','Results:','Values below LLOQ',...
    'Outliers','Missing obligatory peaks','Too few peaks',...
    'Accepted after probability check','Warnings';'' datestr(now) getenv('UserName') ...
    getenv('COMPUTERNAME') getenv('OS') version ''...
    ['''' versiondate] filename input_filetype xls_integralsheet xls_integralarea...
    'Not used' 'Not used' 'Not used' 'Not used' 'Not used' 'Not used' 'Not used' 'Not used'...
    ['''' num2str(spikeinfactor)] ['''' num2str(dilutionfactor)] ['''' num2str(Outliervalue)]...
    ['''' num2str(Peakthreshold)] singlepeaksmissingallowed_choice 'Not used' 'Not used'...
    crea_correction_compound dilution_choice means_choice outputfile output_filetype...
    '' 'Not used' num2str(NumberOutliers) 'Not used' 'Not used' 'Not used' 'None'};

if scale2refsubst==1
    Configuration_titles(2,26)={refsubstname};
    Configuration_titles(2,27)={num2str(refsubstanceconcentration)};
end        
if no_calibrationfactors==1
    Configuration_titles(2,13)={calibrationfactorsfile};
    Configuration_titles(2,14)={corr_filetype};
    Configuration_titles(2,15)={calibrationfilepage};
    Configuration_titles(2,16)={calibrationfilearea};
    %Configuration_titles(2,26)={'Not used'};
    Configuration_titles(2,36)={num2str(Obligatorypeakmissing)};
    Configuration_titles(2,37)={num2str(numberpeakcountlowerthanthreshold)};
    Configuration_titles(2,38)={num2str(numberpeakcountlowerthanthreshold-numberpeakcountlowerthanthresholdexcluded)};
end   
if Crea_Count==0
    Configuration_titles(2,28)={'Not used'};
end
if dontuse_LLOQS==1
    Configuration_titles(2,17)={LLOQfile};
    Configuration_titles(2,18)={LLOQ_filetype};
    Configuration_titles(2,19)={LLOQpage};
    Configuration_titles(2,20)={LLOQrange};
    Configuration_titles(2,34)={num2str(NumberbelowLLOQ)};
end  
if not(isempty(errorlist))
     for i1=1:length(errorlist)
         Configuration_titles(2,38+i1)=errorlist(i1);
     end;
end
if ishandle(waitbar_progress)
    waitbar(6/7,waitbar_progress,'Writing output file(s)...')
end
if output_id==1 %xls output file
    %fprintf('Writing xls result file... ');
    %tic;
    warning off MATLAB:xlswrite:AddSheet;
    if Crea_Count>0||dfexist==1
        resultsheetname='Uncorrected Results';
    else
        resultsheetname='Results';
    end
    ValuesTitlecolumnshort_total=ValuesTitlecolumn_total;
    ValuesTitlecolumnshort_total{1}='';%create a title line without "mmol/L"
    Originalvaluesforxls=ValuesTitlecolumn_total';
    for i1=1:(length(ValuesTitlecolumn_total)-1)
        for j=1:length(ValuesTitlerow)
            Originalvaluesforxls{j+1,1}=ValuesTitlerow{j};
            Originalvaluesforxls{j+1,i1+1}=Valuesuncorrected(i1,j);
        end
    end
    xlswrite(outputfileminusextension,Originalvaluesforxls,'Original Values','A1');
    pause(0.04);%pause for a small time to let windows redraw
    clear Originalvaluesforxls;
    %xlswrite(outputfileplusextension,Outlierslist,'Outliers','A1');
    xlswrite(outputfileminusextension,Outlierslist,'Outliers','A1');
    pause(0.04);%pause for a small time to let windows redraw
    %writing number of used peaks
    xlswrite(outputfileminusextension,Used_peaks_string2,'Used Peaks','A1');
    pause(0.04);%pause for a small time to let windows redraw
    if i_MEAN>0
        ValuesMEANdiscardwithout0forxls=ValuesTitlecolumnshort_total';
        for i1=1:(length(ValuesTitlecolumnshort_total)-1)
            for j=1:length(ValuesTitlerowMEAN)
                ValuesMEANdiscardwithout0forxls{j+1,1}=ValuesTitlerowMEAN{j};
                ValuesMEANdiscardwithout0forxls{j+1,i1+1}=ValuesMEANdiscardwithout0(i1,j);
            end
        end
        xlswrite(outputfileminusextension,ValuesMEANdiscardwithout0forxls,'Mean','A1');
        pause(0.04);%pause for a small time to let windows redraw
        clear ValuesMEANdiscardwithout0forxls;
    end
    pause(0.04);%pause for a small time to let windows redraw
    %Write configuration information
    xlswrite(outputfileminusextension,Configuration_titles','Configuration','A1');
    pause(0.04);%pause for a small time to let windows redraw
    %write final results
    Valueswithout0forxls=ValuesTitlecolumn_total';
    for i1=1:(length(ValuesTitlecolumn_total)-1)
        for j=1:length(ValuesTitlerowplusextra)
            Valueswithout0forxls{j+1,1}=ValuesTitlerowplusextra{j};
            Valueswithout0forxls{j+1,i1+1}=Valueswithout0(i1,j);
        end
    end
    xlswrite(outputfileminusextension,Valueswithout0forxls,resultsheetname,'A1');
    pause(0.04);%pause for a small time to let windows redraw
    clear Valueswithout0forxls;
    if Crea_Count>0
        normalize_compound=['Normalized to ' crea_correction_compound];
        ValuesCreaforxls=ValuesTitlecolumnshort_total';
        for i1=1:(length(ValuesTitlecolumnshort_total)-1)
            for j=1:length(ValuesTitlerow)
                ValuesCreaforxls{j+1,1}=ValuesTitlerow{j};
                ValuesCreaforxls{j+1,i1+1}=ValuesCrea(i1,j);
            end
        end
        xlswrite(outputfileminusextension,ValuesCreaforxls,normalize_compound,'A1');
        pause(0.04);%pause for a small time to let windows redraw
        clear ValuesCreaforxls;
    end
    if dfexist==1
        Valuesdfforxls=ValuesTitlecolumnshort_total';
        for i1=1:(length(ValuesTitlecolumnshort_total)-1)
            for j=1:length(ValuesTitlerow)
                Valuesdfforxls{j+1,1}=ValuesTitlerow{j};
                Valuesdfforxls{j+1,i1+1}=Valuesdf(i1,j);
            end
        end
        xlswrite(outputfileminusextension,Valuesdfforxls,'Dilution Corrected Results','A1');
        pause(0.04);%pause for a small time to let windows redraw
        clear Valuesdfforxls;
    end
    pause(0.04);%pause for a small time to let windows redraw
    %t=toc;
    %fprintf('Done in %g seconds.\n',t);
end%end xls output
%
if output_id==2%tab stop separated txt output
    %fprintf('Writing .txt result files... ');
    %tic;
    if Crea_Count>0||dfexist==1
        resultsheetname='Uncorrected_Results';
    else
        resultsheetname='Results';
    end
    %write original values
    outputfileplusextension=strcat(outputfileminusextension,'_Original.txt');
    %convert numeric data into string data
    Results_string=ValuesTitlecolumn_total';
    for i1=1:length(ValuesTitlerow)
        Results_string(i1+1,1)=ValuesTitlerow(i1);
        for j=1:length(Valuesuncorrected(:,1))
            Results_string(i1+1,j+1)={num2str(Valuesuncorrected(j,i1))};
        end
    end
    %write numeric data to file
    fid = fopen(outputfileplusextension, 'wt');
    for i1=1:length(Results_string(:,1))
        fprintf(fid, '%s\t', Results_string{i1,:});
        fprintf(fid, '\n');
    end
    fclose(fid);
    pause(0.075);%pause for a small time to let windows redraw
    
    %write outliers
    outputfileplusextension=strcat(outputfileminusextension,'_Outliers.txt');
    fid = fopen(outputfileplusextension, 'wt');
    for i1=1:length(Outlierslist(:,1))
        fprintf(fid, '%s\t', Outlierslist{i1,:});
        fprintf(fid, '\n');
    end
    fclose(fid);
    pause(0.075);%pause for a small time to let windows redraw
     
    %write normalized values
    if Crea_Count>0
        outputfileplusextension=strcat(outputfileminusextension,'_Normalized.txt');
        
        %convert numeric data into string data
        Results_string=ValuesTitlecolumn_total';
        Results_string(1)={''};
        for i1=1:length(ValuesTitlerow)
            Results_string(i1+1,1)=ValuesTitlerow(i1);
            for j=1:length(ValuesCrea(:,1))
                Results_string(i1+1,j+1)={num2str(ValuesCrea(j,i1))};
            end
        end
        %write numeric data to file
        fid = fopen(outputfileplusextension, 'wt');
        for i1=1:length(Results_string(:,1))
            fprintf(fid, '%s\t', Results_string{i1,:});
            fprintf(fid, '\n');
        end
        fclose(fid);
        pause(0.075);%pause for a small time to let windows redraw
    end
    
    %write dilution corrected values
    if dfexist==1
        outputfileplusextension=strcat(outputfileminusextension,'_Dilution.txt');
        %convert numeric data into string data
        Results_string=ValuesTitlecolumn_total';
        Results_string(1)={''};
        for i1=1:length(ValuesTitlerow)
            Results_string(i1+1,1)=ValuesTitlerow(i1);
            for j=1:length(Valuesdf(:,1))
                Results_string(i1+1,j+1)={num2str(Valuesdf(j,i1))};
            end
        end
        %write numeric data to file
        fid = fopen(outputfileplusextension, 'wt');
        for i1=1:length(Results_string(:,1))
            fprintf(fid, '%s\t', Results_string{i1,:});
            fprintf(fid, '\n');
        end
        fclose(fid);
        pause(0.075);%pause for a small time to let windows redraw
    end    
    %write means
    if i_MEAN>0
        outputfileplusextension=strcat(outputfileminusextension,'_Means.txt');
        %convert numeric data into string data
        Results_string=ValuesTitlecolumn_total';
        Results_string(1)={''};
        for i1=1:length(ValuesTitlerowMEAN)
            Results_string(i1+1,1)=ValuesTitlerowMEAN(i1);
            for j=1:length(ValuesMEANdiscardwithout0(:,1))
                Results_string(i1+1,j+1)={num2str(ValuesMEANdiscardwithout0(j,i1))};
            end
        end
        %write numeric data to file
        fid = fopen(outputfileplusextension, 'wt');
        for i1=1:length(Results_string(:,1))
            fprintf(fid, '%s\t', Results_string{i1,:});
            fprintf(fid, '\n');
        end
        fclose(fid);
 
        pause(0.075);%pause for a small time to let windows redraw
    end

    %write number of used peaks
    outputfileplusextension=strcat(outputfileminusextension,'_Used_Peaks.txt');
    fid = fopen(outputfileplusextension, 'wt');
    for i1=1:length(Used_peaks_string(:,1))
        fprintf(fid, '%s\t', Used_peaks_string{i1,:});
        fprintf(fid, '\n');
    end
    fclose(fid);
    pause(0.075);%pause for a small time to let windows redraw
    
    %write configuration information
    outputfileplusextension=strcat(outputfileminusextension,'_Configuration.txt');
    fid = fopen(outputfileplusextension, 'wt');
    for i1=1:length(Configuration_titles(1,:))
        fprintf(fid, '%s\t%s', Configuration_titles{:,i1});
        fprintf(fid, '\n');
    end
    fclose(fid);
    pause(0.075);%pause for a small time to let windows redraw
    
    %write final results
    %outputfileplusextension=strcat(outputfileminusextension,'_',resultsheetname,'_results.txt');
    outputfileplusextension=strcat(outputfileminusextension,'_',resultsheetname,'.txt');
    %convert numeric data into string data
    Results_string=ValuesTitlecolumn_total';
    for i1=1:length(ValuesTitlerowplusextra)
        Results_string(i1+1,1)=ValuesTitlerowplusextra(i1);
        for j=1:length(Valueswithout0(:,1))
            if isequalwithequalnans(Valueswithout0(j,i1),NaN)
                Results_string(i1+1,j+1)={'0'};
            else
                Results_string(i1+1,j+1)={num2str(Valueswithout0(j,i1))};
            end
        end
    end
    %write numeric data to file
    fid = fopen(outputfileplusextension, 'wt');
    for i1=1:length(Results_string(:,1))
        fprintf(fid, '%s\t', Results_string{i1,:});
        fprintf(fid, '\n');
    end
    fclose(fid);
    pause(0.075);%pause for a small time to let windows redraw

    %t=toc;
    %fprintf('Done in %g seconds.\n',t);
end
%
if ishandle(waitbar_progress)
    waitbar(7/7,waitbar_progress,'Calculation finished, opening result file...')
end
%msgbox(sprintf('Values below LLOQ: %d\nOutliers: %d\nMissing obligatory peaks: %d\nLess peaks than threshold: %d\nAccepted after probability check: %d\nResults saved to: %s',...
%    NumberbelowLLOQ,NumberOutliers,Obligatorypeakmissing,...
%    numberpeakcountlowerthanthreshold,(numberpeakcountlowerthanthreshold-...
%    numberpeakcountlowerthanthresholdexcluded),outputfileplusextension),'Quantification successful');
%The follwoing procedure is necessary to avoid an error occuring using
%MATLAB 7.1 in combination with Excel 2003
if exist(outputfileplusextension)==2
    %winopen(outputfileplusextension)
else
    if exist (strcat(outputfileminusextension,'.xls'))==2
        try
            [status1,sheets1,format1] =xlsfinfo(strcat(outputfileminusextension,'.xls'));
            %this command does not work in older MATLAB version, therfore
            %"try". in older version, always xls format is used
        end
        if exist('format1')==1
            if strcmp(format1,'xlOpenXMLWorkbook')==1
                %change file extension to xlsx
                movefile(strcat(outputfileminusextension,'.xls'),outputfileplusextension);
                %outputfileplusextension=strcat(outputfileminusextension,'.xls');
            end
            clear('status1','sheets1','format1');
        end
    end
end
if exist(outputfileplusextension)==2
    winopen(outputfileplusextension);
else
    try
        winopen(strcat(outputfileminusextension,'.xls'));
    end
end
try
    close(waitbar_progress)
end
catch
    clear err;
    err=lasterror;
    msgbox(err.message,'Error','error');
    clear err;
end

% --- Executes on button press in openintegrals.
function openintegrals_Callback(hObject, eventdata, handles)

global IntegralFolder
cd(IntegralFolder);

warning off all;
[filename,filepath,inputfile_id]=uigetfile({'*.txt',...
    'AMIX Analytic Profiler file (.txt)';'*.txt','Tab stop separated text (.txt)';...
    '*.xls','MS Excel file (.xls)';'*.*','All files (.*)'},'Open integral value file');
filename=strcat(filepath,filename);

if inputfile_id>0%enable "save as"-button
    IntegralFolder=filepath;
    cd(IntegralFolder);

    if inputfile_id==4
        inputfile_id=2;
    end
    %for excel files enable spreadsheet and range fields
    if inputfile_id==3
        set(handles.xlssheet,'Enable','on')
        set(handles.xlsrange,'Enable','on')
        set(handles.xlsrange_text,'Enable','on')
        set(handles.xlssheet_text,'Enable','on')
    else
        set(handles.xlssheet,'Enable','off')
        set(handles.xlsrange,'Enable','off')
        set(handles.xlsrange_text,'Enable','off')
        set(handles.xlssheet_text,'Enable','off')
    end
    set(handles.integral_file_entry,'String',filename);
    switch inputfile_id
        case 1
            set(handles.integral_popupmenu,'String','AMIX .txt')
        case 2
            set(handles.integral_popupmenu,'String','.txt')
        case 3
            set(handles.integral_popupmenu,'String','Excel')
    end
    set(handles.integral_popupmenu,'Value',inputfile_id)
end


% --- Executes on button press in opencalibrationfactors.
function opencalibrationfactors_Callback(hObject, eventdata, handles)

global InformationFolder
cd(InformationFolder);

warning off all;
[corr_filename,corr_filepath,corr_id]=uigetfile({'*.xls',...
    'MS Excel file (.xls)';'*.txt','Tab stop separated text (.txt)';...
    '*.*','All files (.*)'},'Open peak information file');
calibrationfactorsfile=strcat(corr_filepath,corr_filename);

if corr_id>0
    InformationFolder=corr_filepath;
    cd(InformationFolder);
    %if "all files" was used the file is treated as a text file
    if corr_id==3
        corr_id=2;
    end
    %for excel files enable the spreadsheet and range fields
    if corr_id==1
        set(handles.calibsheet,'Enable','on')
        set(handles.calibrange,'Enable','on')
        set(handles.calibsheet_text,'Enable','on')
        set(handles.calibrange_text,'Enable','on')
    else
        if corr_id==3
            corr_id=2;
        end
        set(handles.calibsheet,'Enable','off')
        set(handles.calibrange,'Enable','off')
        set(handles.calibsheet_text,'Enable','off')
        set(handles.calibrange_text,'Enable','off')
    end
    switch corr_id
        case 1
            set(handles.peak_inormation_popupmenu,'String','Excel')
        case 2
            set(handles.peak_inormation_popupmenu,'String','.txt')
    end
    set(handles.peak_inormation_popupmenu,'Value',corr_id)
    set(handles.information_file_entry,'String',calibrationfactorsfile);
end



% --- Executes on button press in openLLOQS.
function openLLOQS_Callback(hObject, eventdata, handles)

global LLOQFolder
cd(LLOQFolder);

warning off all;
[LLOQ_filename,LLOQ_filepath,LLOQ_id]=uigetfile({'*.xls',...
    'MS Excel file (.xls)';'*.txt','Tab stop separated text (.txt)';...
    '*.*','All files (.*)'},'Open LLOQ factor file');
LLOQfile=strcat(LLOQ_filepath,LLOQ_filename);

if LLOQ_id>0
    LLOQFolder=LLOQ_filepath;
    cd(LLOQFolder);
    %for excel files enable spreadsheet and range fields
    if LLOQ_id==1
        set(handles.LLOQsheet,'Enable','on')
        set(handles.LLOQrange,'Enable','on')
        set(handles.LLOQsheet_text,'Enable','on')
        set(handles.LLOQrange_text,'Enable','on')
    else
        if LLOQ_id==3
            LLOQ_id=2;
        end
        set(handles.LLOQsheet,'Enable','off')
        set(handles.LLOQrange,'Enable','off')
        set(handles.LLOQsheet_text,'Enable','off')
        set(handles.LLOQrange_text,'Enable','off')
    end
    set(handles.LLOQ_file_entry,'String',LLOQfile);
    switch LLOQ_id
        case 1
            set(handles.LLOQ_popupmenu,'String','Excel')
        case 2
            set(handles.LLOQ_popupmenu,'String','.txt')
    end
    set(handles.LLOQ_popupmenu,'Value',LLOQ_id)
    
end



% --- Executes on button press in noindividualcalibfactors.
function noindividualcalibfactors_Callback(hObject, eventdata, handles)
if get(hObject,'Value')==1
    set(handles.opencalibrationfactors,'Enable','on')
    %set(handles.refsubstconc,'Enable','off')
    %set(handles.refsubstconc_text,'Enable','off')
    corr_id = get(handles.peak_inormation_popupmenu,'Value');
    if corr_id==1
        set(handles.calibsheet,'Enable','on')
        set(handles.calibrange,'Enable','on')
        set(handles.calibsheet_text,'Enable','on')
        set(handles.calibrange_text,'Enable','on')
    end
    set(handles.information_file_entry,'Enable','on')
    set(handles.peak_inormation_popupmenu,'Enable','inactive')
    set(handles.information_file_entry_text,'Enable','on')
    set(handles.peak_inormation_popupmenu_text,'Enable','on')
else
    set(handles.opencalibrationfactors,'Enable','off')
    set(handles.calibsheet,'Enable','off')
    set(handles.calibsheet_text,'Enable','off')
    set(handles.calibrange_text,'Enable','off')
    set(handles.calibrange,'Enable','off')
    %set(handles.refsubstconc,'Enable','on')
    %set(handles.refsubstconc_text,'Enable','on')
    set(handles.information_file_entry,'Enable','off')
    set(handles.peak_inormation_popupmenu,'Enable','off')
    set(handles.information_file_entry_text,'Enable','off')
    set(handles.peak_inormation_popupmenu_text,'Enable','off')
end

% --- Executes on button press in noLLOQs.
function noLLOQs_Callback(hObject, eventdata, handles)
if get(hObject,'Value')==1
    set(handles.openLLOQS,'Enable','on')
    set(handles.LLOQ_file_entry,'Enable','on')
    set(handles.LLOQ_popupmenu,'Enable','inactive')
    LLOQ_id=get(handles.LLOQ_popupmenu,'Value');
    set(handles.LLOQ_file_entry_text,'Enable','on')
    set(handles.LLOQ_popupmenu_text,'Enable','on')
    if LLOQ_id==1
        set(handles.LLOQsheet,'Enable','on')
        set(handles.LLOQrange,'Enable','on')
        set(handles.LLOQsheet_text,'Enable','on')
        set(handles.LLOQrange_text,'Enable','on')
    end
else
    set(handles.openLLOQS,'Enable','off')
    set(handles.LLOQsheet,'Enable','off')
    set(handles.LLOQsheet_text,'Enable','off')
    set(handles.LLOQrange_text,'Enable','off')
    set(handles.LLOQrange,'Enable','off')
    set(handles.LLOQ_file_entry,'Enable','off')
    set(handles.LLOQ_popupmenu,'Enable','off')
    set(handles.LLOQ_file_entry_text,'Enable','off')
    set(handles.LLOQ_popupmenu_text,'Enable','off')
end


function xlsrange_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function xlsrange_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function xlssheet_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function xlssheet_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in creanorm.
function creanorm_Callback(hObject, eventdata, handles)

if get(hObject,'Value')==0
    set(handles.creanormname,'Enable','off')
else
    set(handles.creanormname,'Enable','on')
end

% --- Executes on button press in dilcorr.
function dilcorr_Callback(hObject, eventdata, handles)


% --- Executes on button press in meancalc.
function meancalc_Callback(hObject, eventdata, handles)


function outl_thr_Callback(hObject, eventdata, handles)



% --- Executes during object creation, after setting all properties.
function outl_thr_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function peak_thr_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function peak_thr_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function corrfactor_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function corrfactor_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function dilfactor_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function dilfactor_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in refsubstance.
function refsubstance_Callback(hObject, eventdata, handles)
if get(hObject,'Value')==0
    set(handles.refsubstancename,'Enable','off')
    set(handles.refsubstconc,'Enable','off')
    set(handles.refsubstconc_text,'Enable','off')
else
    set(handles.refsubstancename,'Enable','on')
    set(handles.refsubstconc,'Enable','on')
    set(handles.refsubstconc_text,'Enable','on')
end


function refsubstancename_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function refsubstancename_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function creanormname_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function creanormname_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in help.
function help_Callback(hObject, eventdata, handles)

winopen('manual.pdf')


function LLOQsheet_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function LLOQsheet_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function LLOQrange_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function LLOQrange_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function calibsheet_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function calibsheet_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function calibrange_Callback(hObject, eventdata, handles)



% --- Executes during object creation, after setting all properties.
function calibrange_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function refsubstconc_Callback(hObject, eventdata, handles)



% --- Executes during object creation, after setting all properties.
function refsubstconc_CreateFcn(hObject, eventdata, handles)

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in exit.
function exit_Callback(hObject, eventdata, handles)

close all hidden


% --- Executes on button press in saveparameters.
function saveparameters_Callback(hObject, eventdata, handles)

global OriginalFolder LLOQFolder InformationFolder
cd(OriginalFolder)

LLOQFolder1=LLOQFolder;
InformationFolder1=InformationFolder;
no_calibrationfactors1=get(handles.noindividualcalibfactors,'Value');
refsubstanceconcentration1=get(handles.refsubstconc,'String');
dontuse_LLOQS1=get(handles.noLLOQs,'Value');
scale2refsubst1=get(handles.refsubstance,'Value');
refsubstname1=get(handles.refsubstancename,'String');
crea_correction1=get(handles.creanorm,'Value');
singlepeaksmissing1=get(handles.singlepeaksmissing,'Value');
crea_correction_compound1=get(handles.creanormname,'String');
dil_correction1=get(handles.dilcorr,'Value');
mean_calculation1=get(handles.meancalc,'Value');
xls_integralsheet1=get(handles.xlssheet,'String');
xls_integralarea1=get(handles.xlsrange,'String');
dilutionfactor1=get(handles.dilfactor,'String');
spikeinfactor1=get(handles.corrfactor,'String');
Outliervalue1=get(handles.outl_thr,'String');
Peakthreshold1=get(handles.peak_thr,'String');
LLOQ_id1=get(handles.LLOQ_popupmenu,'Value');
corr_id1=get(handles.peak_inormation_popupmenu,'Value');
inputfile_id1=get(handles.integral_popupmenu,'Value');
information_file_entry1=get(handles.information_file_entry,'String');
LLOQ_file_entry1=get(handles.LLOQ_file_entry,'String');
information_file_entry2=get(handles.information_file_entry,'Enable');
LLOQ_file_entry2=get(handles.LLOQ_file_entry,'Enable');
peak_inormation_popupmenu2=get(handles.peak_inormation_popupmenu,'Enable');
LLOQ_popupmenu2=get(handles.LLOQ_popupmenu,'Enable');

information_file_entry_text2=get(handles.information_file_entry_text,'Enable');
peak_inormation_popupmenu_text2=get(handles.peak_inormation_popupmenu_text,'Enable');
LLOQ_file_entry_text2=get(handles.LLOQ_file_entry_text,'Enable');
LLOQ_popupmenu_text2=get(handles.LLOQ_popupmenu_text,'Enable');

a1=get(handles.calibsheet,'String');
a2=get(handles.calibrange,'String');
a3=get(handles.LLOQsheet,'String');
a4=get(handles.LLOQrange,'String');
a5=get(handles.xlssheet,'Enable');
a6=get(handles.xlsrange,'Enable');
a7=get(handles.xlsrange_text,'Enable');
a8=get(handles.xlssheet_text,'Enable');
a9=get(handles.openLLOQS,'Enable');
a10=get(handles.LLOQsheet,'Enable');
a11=get(handles.LLOQsheet_text,'Enable');
a12=get(handles.LLOQrange_text,'Enable');
a13=get(handles.LLOQrange,'Enable');
a14=get(handles.refsubstancename,'Enable');
a15=get(handles.opencalibrationfactors,'Enable');
a16=get(handles.calibsheet,'Enable');
a17=get(handles.calibsheet_text,'Enable');
a18=get(handles.calibrange_text,'Enable');
a19=get(handles.calibrange,'Enable');
a21=get(handles.refsubstconc,'Enable');
a23=get(handles.refsubstconc_text,'Enable');

clear handles %otherwise handles will be saved, which leads to access problems when reloaded

[parameter_filename, parameter_path] = uiputfile({'*.mat',...
'Matlab binary files (.mat)'},'Save parameters','parameters.mat');

if not(parameter_filename==0)
    parameter_file=strcat(parameter_path,parameter_filename);
    save(parameter_file);
end


% --------------------------------------------------------------------
function File_Callback(hObject, eventdata, handles)


% --------------------------------------------------------------------
function Help1_Callback(hObject, eventdata, handles)


% --------------------------------------------------------------------
function loadcustomparams_Callback(hObject, eventdata, handles)

global OriginalFolder IntegralFolder InformationFolder LLOQFolder SaveFolder
IntegralFolder=OriginalFolder;
InformationFolder=OriginalFolder;
LLOQFolder=OriginalFolder;
SaveFolder=OriginalFolder;

cd(OriginalFolder);

[parameter_filename, parameter_path,parameter_id] = uigetfile({'*.mat',...
'Matlab binary files (.mat)'},'Load parameters','parameters.mat');

if parameter_id==1
    parameter_file=strcat(parameter_path,parameter_filename);
    load(parameter_file);
    
    LLOQFolder=LLOQFolder1;
    InformationFolder=InformationFolder1;
    
    set(handles.noindividualcalibfactors,'Value',no_calibrationfactors1); 
    set(handles.refsubstconc,'String',refsubstanceconcentration1);
    set(handles.noLLOQs,'Value',dontuse_LLOQS1);
    set(handles.refsubstance,'Value',scale2refsubst1);
    set(handles.refsubstancename,'String',refsubstname1);
    set(handles.creanorm,'Value',crea_correction1);
    set(handles.singlepeaksmissing,'Value',singlepeaksmissing1);
    set(handles.creanormname,'String',crea_correction_compound1);
    set(handles.dilcorr,'Value',dil_correction1);
    set(handles.meancalc,'Value',mean_calculation1);
    set(handles.xlssheet,'String',xls_integralsheet1);
    set(handles.xlsrange,'String',xls_integralarea1);
    set(handles.dilfactor,'String',dilutionfactor1);
    set(handles.corrfactor,'String',spikeinfactor1);
    set(handles.outl_thr,'String',Outliervalue1);
    set(handles.peak_thr,'String',Peakthreshold1);
    set(handles.LLOQ_popupmenu,'Value',LLOQ_id1);
    set(handles.peak_inormation_popupmenu,'Value',corr_id1);
    set(handles.integral_popupmenu,'Value',inputfile_id1);
    set(handles.information_file_entry,'String',information_file_entry1);
    set(handles.LLOQ_file_entry,'String',LLOQ_file_entry1);
    set(handles.information_file_entry,'Enable',information_file_entry2);
    set(handles.LLOQ_file_entry,'Enable',LLOQ_file_entry2);
    set(handles.peak_inormation_popupmenu,'Enable',peak_inormation_popupmenu2);
    set(handles.LLOQ_popupmenu,'Enable',LLOQ_popupmenu2);

    set(handles.information_file_entry_text,'Enable',information_file_entry_text2);
    set(handles.peak_inormation_popupmenu_text,'Enable',peak_inormation_popupmenu_text2);
    set(handles.LLOQ_file_entry_text,'Enable',LLOQ_file_entry_text2);
    set(handles.LLOQ_popupmenu_text,'Enable',LLOQ_popupmenu_text2);

    set(handles.integral_file_entry,'String','');

    set(handles.calibsheet,'String',a1);
    set(handles.calibrange,'String',a2);
    set(handles.LLOQsheet,'String',a3);
    set(handles.LLOQrange,'String',a4);
    set(handles.xlssheet,'Enable',a5);
    set(handles.xlsrange,'Enable',a6);
    set(handles.xlsrange_text,'Enable',a7);
    set(handles.xlssheet_text,'Enable',a8);
    set(handles.openLLOQS,'Enable',a9);
    set(handles.LLOQsheet,'Enable',a10);
    set(handles.LLOQsheet_text,'Enable',a11);
    set(handles.LLOQrange_text,'Enable',a12);
    set(handles.LLOQrange,'Enable',a13);
    set(handles.refsubstancename,'Enable',a14);
    set(handles.opencalibrationfactors,'Enable',a15);
    set(handles.calibsheet,'Enable',a16);
    set(handles.calibsheet_text,'Enable',a17);
    set(handles.calibrange_text,'Enable',a18);
    set(handles.calibrange,'Enable',a19);
    set(handles.refsubstconc,'Enable',a21);
    set(handles.refsubstconc_text,'Enable',a23);
end

    
function information_file_entry_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function information_file_entry_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function LLOQ_file_entry_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function LLOQ_file_entry_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function integral_file_entry_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function integral_file_entry_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on selection change in integral_popupmenu.
function integral_popupmenu_Callback(hObject, eventdata, handles)

% inputfile_id = get(hObject,'Value');
% if inputfile_id==3
%     set(handles.xlssheet,'Enable','on')
%     set(handles.xlsrange,'Enable','on')
%     set(handles.xlsrange_text,'Enable','on')
%     set(handles.xlssheet_text,'Enable','on')
% else
%     set(handles.xlssheet,'Enable','off')
%     set(handles.xlsrange,'Enable','off')
%     set(handles.xlsrange_text,'Enable','off')
%     set(handles.xlssheet_text,'Enable','off')
% end



% --- Executes during object creation, after setting all properties.
function integral_popupmenu_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on selection change in Peak_inormation_popupmenu.
function Peak_inormation_popupmenu_Callback(hObject, eventdata, handles)


% --- Executes during object creation, after setting all properties.
function Peak_inormation_popupmenu_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on selection change in LLOQ_popupmenu.
function LLOQ_popupmenu_Callback(hObject, eventdata, handles)

% LLOQ_id = get(hObject,'Value');
% %for excel files activate spreadsheet and range fields
% if LLOQ_id==1
%     set(handles.LLOQsheet,'Enable','on')
%     set(handles.LLOQrange,'Enable','on')
%     set(handles.LLOQsheet_text,'Enable','on')
%     set(handles.LLOQrange_text,'Enable','on')
% else
%     set(handles.LLOQsheet,'Enable','off')
%     set(handles.LLOQrange,'Enable','off')
%     set(handles.LLOQsheet_text,'Enable','off')
%     set(handles.LLOQrange_text,'Enable','off')
% end


% --- Executes during object creation, after setting all properties.
function LLOQ_popupmenu_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on selection change in peak_inormation_popupmenu.
function peak_inormation_popupmenu_Callback(hObject, eventdata, handles)
    %for excel files enable the spreadsheet and range fields
% corr_id = get(hObject,'Value');
% if corr_id==1
%     set(handles.calibsheet,'Enable','on')
%     set(handles.calibrange,'Enable','on')
%     set(handles.calibsheet_text,'Enable','on')
%     set(handles.calibrange_text,'Enable','on')
% else
%     set(handles.calibsheet,'Enable','off')
%     set(handles.calibrange,'Enable','off')
%     set(handles.calibsheet_text,'Enable','off')
%     set(handles.calibrange_text,'Enable','off')
% end


% --- Executes during object creation, after setting all properties.
function peak_inormation_popupmenu_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




% --- Executes on button press in singlepeaksmissing.
function singlepeaksmissing_Callback(hObject, eventdata, handles)
% hObject    handle to singlepeaksmissing (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of singlepeaksmissing


